@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 2006-2015 VMware, Inc. All rights reserved.
+ * Copyright (C) 2006 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -24,10 +24,10 @@
  *
  */
 
-#define G_LOG_DOMAIN "hgfsClient"
 #include "vmware.h"
 #include "guestApp.h"
 #include "vmcheck.h"
+#include "toolsLogger.h"
 #include "escBitvector.h"
 #include "hgfsEscape.h"
 #include "hgfs.h"
@@ -35,11 +35,8 @@
 #include "hgfsProto.h"
 #include "conf.h"
 #include "str.h"
-#include "vmware/tools/log.h"
-#include "vmware/tools/utils.h"
 
 #include "hgfsclient_version.h"
-#include "vm_version.h"
 #include "embed_version.h"
 VM_EMBED_VERSION(HGFSCLIENT_VERSION_STRING);
 
@@ -51,6 +48,7 @@ VM_EMBED_VERSION(HGFSCLIENT_VERSION_STRING);
 
 RpcOut *gChannel = NULL;
 char *gPacketBuffer = NULL;
+static GuestApp_Dict *gConfDict = NULL;
 
 static Bool HgfsClient_Open(HgfsHandle *rootHandle);
 static HgfsFileName *HgfsClient_Read(HgfsHandle rootHandle,
@@ -61,6 +59,124 @@ static Bool HgfsClient_Init(void);
 static Bool HgfsClient_Cleanup(void);
 
 
+/*
+ *-----------------------------------------------------------------------------
+ *
+ * Debug --
+ *
+ *    Debugging output. Useless to the end user.
+ *
+ * Results:
+ *    None.
+ *
+ * Side effects:
+ *    None.
+ *
+ *-----------------------------------------------------------------------------
+ */
+
+void 
+Debug(const char *fmt, // IN: Duh
+      ...)             // IN: Variadic arguments to duh
+{
+#ifdef VMX86_DEVEL
+   va_list args;
+
+   va_start(args, fmt);
+   ToolsLogger_LogV(TOOLSLOG_TYPE_LOG, fmt, args);
+   va_end(args);
+#endif
+}
+
+
+/*
+ *-----------------------------------------------------------------------------
+ *
+ * Log --
+ *
+ *    Log something. Slightly more important than Debug, but less important
+ *    than Warning.
+ *
+ * Results:
+ *    None.
+ *
+ * Side effects:
+ *    None.
+ *
+ *-----------------------------------------------------------------------------
+ */
+
+void 
+Log(const char *fmt, // IN: Duh
+    ...)             // IN: Variadic arguments to duh
+{
+   va_list args;
+
+   va_start(args, fmt);
+   ToolsLogger_LogV(TOOLSLOG_TYPE_LOG, fmt, args);
+   va_end(args);
+}
+
+
+/*
+ *-----------------------------------------------------------------------------
+ *
+ * Warning --
+ *
+ *    Warn the user of something. Probably fairly important, but not as
+ *    critical as Panic.
+ *
+ * Results:
+ *    None.
+ *
+ * Side effects:
+ *    None.
+ *
+ *-----------------------------------------------------------------------------
+ */
+
+void
+Warning(const char *fmt, // IN: Duh
+        ...)             // IN: Variadic arguments to duh
+{
+   va_list args;
+
+   va_start(args, fmt);
+   ToolsLogger_LogV(TOOLSLOG_TYPE_WARNING, fmt, args);
+   va_end(args);
+}
+
+
+/*
+ *-----------------------------------------------------------------------------
+ *
+ * Panic --
+ *
+ *    Warn the user and quit the app. Something very bad must have happened.
+ *
+ * Results:
+ *    None.
+ *
+ * Side effects:
+ *    None.
+ *
+ *-----------------------------------------------------------------------------
+ */
+
+void
+Panic(const char *fmt, // IN: Duh
+      ...)             // IN: Variadic arguments to duh
+{
+   va_list args;
+
+   va_start(args, fmt);
+   ToolsLogger_LogV(TOOLSLOG_TYPE_PANIC, fmt, args);
+   va_end(args);
+
+   exit(255);
+   NOT_REACHED();
+}
+
 /*
  *-----------------------------------------------------------------------------
  *
@@ -319,14 +435,9 @@ static Bool
 HgfsClient_Init(void)
 {
    Bool success = FALSE;
-   GKeyFile *conf = NULL;
 
-   VMTools_LoadConfig(NULL, G_KEY_FILE_NONE, &conf, NULL);
-   VMTools_ConfigLogging("hgfsclient", conf, FALSE, FALSE);
-   if (conf != NULL) {
-      g_key_file_free(conf);
-      conf = NULL;
-   }
+   gConfDict = Conf_Load();
+   ToolsLogger_Init("hgfsclient", gConfDict);
 
    if (!VmCheck_IsVirtualWorld()) {
       Warning("This application must be run in a Virtual Machine.\n");
@@ -390,6 +501,10 @@ HgfsClient_Cleanup(void)
          success = FALSE;
       }
    }
+   ToolsLogger_Cleanup();
+   if (gConfDict) {
+      GuestApp_FreeDict(gConfDict);
+   }
    return success;
 }
 
