@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 1998-2015 VMware, Inc. All rights reserved.
+ * Copyright (C) 1998 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -97,20 +97,17 @@ XXX document the escaping/unescaping process: rationale for which chars we escap
 
 
 /*
- * The dictionary line format:
- *
- *    <ws> <name> <ws> = <ws> <value> <ws> <comment>
- * or
- *    <ws> <name> <ws> = <ws> " <quoted-value> " <ws> <comment>
- *
- * where
- *    <name> does not contain any whitespace or = or #
- *    <value> does not contain any double-quote or #
- *    <quoted-value> does not contain any double-quote
- *    <comment> begins with # and ends at the end of the line
- *    <ws> is a sequence spaces and/or tabs
- *    <comment> and <ws> are optional
- */
+XXX document the dict format:
+
+     whitespaces <name> whitespaces '=' whitespaces <value> whitespaces comment
+  or
+     whitespaces <name> whitespaces '=' whitespaces '"' <value> '"' whitespaces comment
+
+  where:
+
+  . <name> does not contain any whitespace or = or pound
+  . <value> does not contain any double-quote or pound
+*/
 
 
 /*
@@ -243,7 +240,7 @@ DictLL_UnmarshalLine(const char *buf,   // IN: buffer to parse
       *value = NULL;
       return NULL;
    }
-
+   
    /* Find end of this line, beginning of next. */
    lineEnd = memchr(buf, '\n', bufSize);
    if (lineEnd != NULL) {
@@ -287,7 +284,7 @@ DictLL_UnmarshalLine(const char *buf,   // IN: buffer to parse
 
    myName = BufDup(nBegin, nEnd - nBegin);
    myValue = Escape_Undo('|', vBegin, vEnd - vBegin, NULL);
-   VERIFY(myValue);
+   ASSERT_MEM_ALLOC(myValue);
 
    *line = myLine;
    *name = myName;
@@ -339,18 +336,18 @@ DictLL_ReadLine(FILE *stream, // IN: stream to read
    ASSERT(line);
    ASSERT(name);
    ASSERT(value);
-
+ 
    *line = NULL;
    *name = NULL;
    *value = NULL;
-
+   
    switch (StdIO_ReadNextLine(stream, &myLine, 0, &myLineLen)) {
    case StdIO_Error:
       return 0;
-
+ 
    case StdIO_EOF:
       return 1;
-
+ 
    case StdIO_Success:
       if (DictLL_UnmarshalLine(myLine, myLineLen,
                                line, name, value) == NULL) {
@@ -386,22 +383,22 @@ DictLL_ReadLine(FILE *stream, // IN: stream to read
 
 Bool
 DictLL_MarshalLine(DynBuf *output,    // IN/OUT: output buffer
-                   char const *name,  // IN/OPT: name to marshal
+                   char const *name,  // IN: name to marshal
                    char const *value) // IN: value to marshal
 {
    size_t size;
 
    if (name) {
       /*
-       * Double quote, pipe, 0x7F, and all control characters but
+       * Double quote, pound, pipe, 0x7F, and all control characters but
        * tab --hpreg
-       * 0x80 to 0xff are unescaped so characters in encodings
-       * like UTF-8 will be displayed normally.
+       * XXX Why 7F? Why not also 84 and 85 and 90 which do funny things in a
+       *     xterm?
        */
       static int const toEscape[] = {
          1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1,
          1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
-         0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+         0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
          0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
          0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
          0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
