@@ -1834,8 +1834,8 @@ File_PrependToPath(const char *searchPath,   // IN
    ASSERT(searchPath);
    ASSERT(elem);
 
-   newPath = Str_SafeAsprintf(NULL, "%s" FILE_SEARCHPATHTOKEN "%s",
-                          elem, searchPath);
+   newPath = Str_SafeAsprintf(NULL, "%s%s%s", elem, FILE_SEARCHPATHTOKEN,
+                              searchPath);
 
    n = strlen(elem);
    path = newPath + n + 1;
@@ -1885,39 +1885,43 @@ File_FindFileInSearchPath(const char *fileIn,       // IN
                           const char *cwd,          // IN
                           char **result)            // OUT
 {
-   Bool found = FALSE;
-   char *cur = NULL;
+   char *cur;
+   char *tok;
+   Bool found;
+   char *saveptr;
    char *sp = NULL;
    char *file = NULL;
-   char *tok;
 
    ASSERT(fileIn);
    ASSERT(cwd);
    ASSERT(searchPath);
 
    /*
-    * First check the usual places, the fullpath, and the cwd.
+    * First check the usual places - the fullpath or the cwd.
     */
 
    if (File_IsFullPath(fileIn)) {
       cur = Util_SafeStrdup(fileIn);
    } else {
-      cur = Str_SafeAsprintf(NULL, "%s"DIRSEPS"%s", cwd, fileIn);
+      cur = Str_SafeAsprintf(NULL, "%s%s%s", cwd, DIRSEPS, fileIn);
    }
 
    if (File_Exists(cur)) {
-      goto found;
+      goto done;
    }
+
    free(cur);
+   cur = NULL;
 
    /*
     * Didn't find it in the usual places so strip it to its bare minimum and
     * start searching.
     */
+
    File_GetPathName(fileIn, NULL, &file);
 
    sp = Util_SafeStrdup(searchPath);
-   tok = strtok(sp, FILE_SEARCHPATHTOKEN);
+   tok = strtok_r(sp, FILE_SEARCHPATHTOKEN, &saveptr);
 
    while (tok) {
       if (File_IsFullPath(tok)) {
@@ -1927,37 +1931,44 @@ File_FindFileInSearchPath(const char *fileIn,       // IN
          /* Relative Path.  Prepend the cwd. */
          if (Str_Strcasecmp(tok, ".") == 0) {
             /* Don't append "." */
-            cur = Str_SafeAsprintf(NULL, "%s"DIRSEPS"%s", cwd, file);
+            cur = Str_SafeAsprintf(NULL, "%s%s%s", cwd, DIRSEPS, file);
          } else {
-            cur = Str_SafeAsprintf(NULL, "%s"DIRSEPS"%s"DIRSEPS"%s", cwd,
-                                   tok, file);
+            cur = Str_SafeAsprintf(NULL, "%s%s%s%s%s", cwd, DIRSEPS, tok,
+                                   DIRSEPS, file);
          }
       }
 
       if (File_Exists(cur)) {
-         goto found;
+         break;
       }
+
       free(cur);
-      tok = strtok(NULL, FILE_SEARCHPATHTOKEN);
+      cur = NULL;
+
+      tok = strtok_r(NULL, FILE_SEARCHPATHTOKEN, &saveptr);
+   }
+
+done:
+   if (cur) {
+      found = TRUE;
+
+      if (result) {
+         *result = File_FullPath(cur);
+
+         if (*result == NULL) {
+            found = FALSE;
+         }
+      }
+
+      free(cur);
+   } else {
+      found = FALSE;
    }
 
-  exit:
    free(sp);
    free(file);
+
    return found;
-
-  found:
-   ASSERT(cur);
-   found = TRUE;
-   if (result) {
-      *result = File_FullPath(cur);
-
-      if (*result == NULL) {
-         found = FALSE;
-      }
-   }
-   free(cur);
-   goto exit;
 }
 
 
