@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 2008-2019,2022 VMware, Inc. All rights reserved.
+ * Copyright (C) 2008 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -16,20 +16,6 @@
  *
  *********************************************************/
 
-/*********************************************************
- * The contents of this file are subject to the terms of the Common
- * Development and Distribution License (the "License") version 1.0
- * and no later version.  You may not use this file except in
- * compliance with the License.
- *
- * You can obtain a copy of the License at
- *         http://www.opensource.org/licenses/cddl1.php
- *
- * See the License for the specific language governing permissions
- * and limitations under the License.
- *
- *********************************************************/
-
 /*
  * hgfsEscape.c --
  *
@@ -40,17 +26,17 @@
 #ifdef __KERNEL__
 #  include "driver-config.h"
 #  include <linux/string.h>
-#elif defined __FreeBSD__
-#   if defined _KERNEL
+#elif defined(__FreeBSD__)
+#   if defined(_KERNEL)
 #      include <sys/libkern.h>
 #      define strchr(s,c)       index(s,c)
 #   else
 #      include <string.h>
 #   endif
-#   define memmove(s1,s2,n) bcopy(s2,s1,n)
-#elif defined __APPLE__ && defined KERNEL
+#   define memmove(s1,s2,n) bcopy(s2,s1,n) 
+#elif defined(__APPLE__) && defined(KERNEL)
 #  include <string.h>
-#elif !defined sun
+#elif !defined(sun)
 #  include <stdlib.h>
 #  include <string.h>
 #else
@@ -67,7 +53,7 @@
 
 /* These characters are illegal in Windows file names. */
 const char* HGFS_ILLEGAL_CHARS = "/\\*?:\"<>|";
-const char* HGFS_SUBSTITUTE_CHARS = "!@#$^&(){";
+const char* HGFS_SUBSTITUTE_CHARS = "!@#$^&(){}";
 /* Last character of a file name in Windows can be neither dot nor space. */
 const char* HGFS_ILLEGAL_LAST_CHARS = ". ";
 
@@ -102,7 +88,7 @@ if (!HgfsProcessLastCharacter(b,s,p,c)) \
 /* There is no special processing for the last character on non-Windows platforms. */
 #define PROCESS_LAST_CHARACTER(b,s,p,c)
 
-#if defined __APPLE__
+#if defined(__APPLE__)
 /* These characters are illegal in MAC OS file names. */
 const char* HGFS_ILLEGAL_CHARS = "/:";
 const char* HGFS_SUBSTITUTE_CHARS = "!&";
@@ -574,19 +560,8 @@ HgfsIsEscapeSequence(char const *bufIn,   // IN: input name
 {
    if (bufIn[offset] == HGFS_ESCAPE_CHAR && offset > 0) {
       char *substitute;
-      if (bufIn[offset - 1] == HGFS_ESCAPE_SUBSTITUE_CHAR && offset > 1) {
-         /*
-          * Possibly a valid sequence, check it must be preceded with a substitute
-          * character or another escape-escape character. Otherwise, HGFS did
-          * not generate this sequence and should leave it alone.
-          */
-         if (bufIn[offset - 2] == HGFS_ESCAPE_SUBSTITUE_CHAR) {
-            return TRUE;
-         }
-         substitute = strchr(HGFS_SUBSTITUTE_CHARS, bufIn[offset - 2]);
-         if (substitute != NULL) {
-            return TRUE;
-         }
+      if (bufIn[offset - 1] == HGFS_ESCAPE_SUBSTITUE_CHAR) {
+         return TRUE;
       }
       substitute = strchr(HGFS_SUBSTITUTE_CHARS, bufIn[offset - 1]);
       if (substitute != NULL) {
@@ -697,9 +672,9 @@ HgfsEscapeEnumerate(char const *bufIn,              // IN:  Buffer with unescape
 
 int
 HgfsEscape_Do(char const *bufIn, // IN:  Buffer with unescaped input
-              uint32 sizeIn,     // IN:  Size of input buffer
-              uint32 sizeBufOut, // IN:  Size of output buffer
-              char *bufOut)      // OUT: Buffer for escaped output
+	           uint32 sizeIn,     // IN:  Size of input buffer
+	           uint32 sizeBufOut, // IN:  Size of output buffer
+	           char *bufOut)      // OUT: Buffer for escaped output
 {
    const char *currentComponent = bufIn;
    uint32 sizeLeft = sizeBufOut;
@@ -729,10 +704,7 @@ HgfsEscape_Do(char const *bufIn, // IN:  Buffer with unescaped input
    }
    while (currentComponent - bufIn < sizeIn) {
       int escapedLength;
-      int componentSize = CPName_GetComponent(currentComponent, end, &next);
-      if (componentSize < 0) {
-         return componentSize;
-      }
+      uint32 componentSize = CPName_GetComponent(currentComponent, end, &next);
 
       escapedLength = HgfsEscapeDoComponent(currentComponent, componentSize,
                                             sizeLeft, outPointer);
@@ -758,7 +730,6 @@ HgfsEscape_Do(char const *bufIn, // IN:  Buffer with unescaped input
  *    On success, the size (excluding the NUL terminator) of the
  *    escaped, NUL terminated buffer.
  *    Returns 0 if the name is a valid Windows file name.
- *    Returns -1 if the name is not a valid file name.
  *
  * Side effects:
  *    None
@@ -775,15 +746,15 @@ HgfsEscape_GetSize(char const *bufIn,    // IN:  Buffer with unescaped input
    const char *end = bufIn + sizeIn;
    const char *next;
 
-   if (sizeIn == 0) { // No need to escape an empty name.
+   if (sizeIn == 0) { // No need toescape empty name.
       return 0;
    }
    if (bufIn[sizeIn - 1] == '\0') {
       /*
-       * In some cases, a NUL-terminated string is passed to HgfsEscape_GetSize,
-       * so it makes sense to support such input even if CPName_GetComponent
+       * In some cases a NUL terminated string is passed to HgfsEscape_GeSize
+       * so it make sense to support such input even if CPName_GetComponent
        * does not. Detect this case and make the input compliant with
-       * CPName_GetComponent by removing the terminating NUL.
+       * CPName_GetComponent by removing terminating NUL.
        */
       end--;
       sizeIn--;
@@ -793,11 +764,7 @@ HgfsEscape_GetSize(char const *bufIn,    // IN:  Buffer with unescaped input
       currentComponent++;
    }
    while (currentComponent - bufIn < sizeIn) {
-      int componentSize = CPName_GetComponent(currentComponent, end, &next);
-      if (componentSize < 0) {
-         Log("%s: failed to calculate escaped name size - name is invalid\n", __FUNCTION__);
-         return -1;
-      }
+      uint32 componentSize = CPName_GetComponent(currentComponent, end, &next);
       result += HgfsEscapeGetComponentSize(currentComponent, componentSize);
       currentComponent = next;
    }
@@ -825,23 +792,21 @@ HgfsEscape_GetSize(char const *bufIn,    // IN:  Buffer with unescaped input
  *-----------------------------------------------------------------------------
  */
 
-uint32
+int
 HgfsEscape_Undo(char *bufIn,       // IN: Characters to be unescaped
                 uint32 sizeIn)     // IN: Number of characters in bufIn
 {
-   uint32 componentSize;
+   uint32 componentSize = strlen(bufIn) + 1;
    uint32 unprocessedSize = sizeIn + 1;
    uint32 result = 0;
    char *currentComponent = bufIn;
-
-   ASSERT(bufIn != NULL);
-
    while (currentComponent != NULL) {
       HgfsEscapeUndoComponent(currentComponent, &unprocessedSize);
       componentSize = strlen(currentComponent) + 1; // Unescaped size
       result += componentSize;
       if (unprocessedSize > 1) {
          currentComponent = currentComponent + componentSize;
+         componentSize = strlen(currentComponent) + 1; // Size of the next component
       } else {
          currentComponent = NULL;
       }
@@ -874,18 +839,15 @@ HgfsEscapeUndoComponent(char   *bufIn,             // IN: Characters to be unesc
                         uint32 *unprocessedLength) // IN: Unprocessed characters
                                                    //     in the whole name
 {
-   size_t sizeIn;
-   char* curOutBuffer;
+   size_t offset;
+   size_t sizeIn = strlen(bufIn);
+   char* curOutBuffer = bufIn;
    char* escapePointer;
+   ASSERT(bufIn);
 
-   ASSERT(bufIn != NULL);
-
-   curOutBuffer = bufIn;
-   sizeIn = strlen(curOutBuffer);
    escapePointer = strchr(curOutBuffer, HGFS_ESCAPE_CHAR);
    while (escapePointer != NULL) {
-      size_t offset = escapePointer - bufIn;
-
+      offset = escapePointer - bufIn;
       if (HgfsIsEscapeSequence(bufIn, offset, sizeIn)) {
          char* substitute = strchr(HGFS_SUBSTITUTE_CHARS, bufIn[offset - 1]);
          if (substitute != NULL) {
