@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 2004-2015 VMware, Inc. All rights reserved.
+ * Copyright (C) 2004 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -29,9 +29,6 @@
 #define _DYNARRAY_H_
 
 #include "dynbuf.h"
-#include "vm_basic_types.h"
-#include "vm_assert.h"
-
 
 typedef struct DynArray {
    DynBuf buf;
@@ -58,166 +55,26 @@ DynArray_Init(DynArray *a, unsigned int count, size_t width);
 void
 DynArray_Destroy(DynArray *a);
 
+void *
+DynArray_AddressOf(const DynArray *a, unsigned int i);
+
+unsigned int
+DynArray_Count(const DynArray *a);
+
 Bool
 DynArray_SetCount(DynArray *a, unsigned int c);
 
-void
-DynArray_QSort(DynArray *a, DynArrayCmp compare);
-
 unsigned int
 DynArray_AllocCount(const DynArray *a);
 
+Bool
+DynArray_Trim(DynArray *a);
 
-/*
- *-----------------------------------------------------------------------------
- *
- * DynArray_Trim --
- *
- *      Resize the array to fit exactly DynArray_Count() elements.
- *
- * Results:
- *      TRUE on success
- *      FALSE on failure (why?  who knows...)
- *
- * Side effects:
- *      Resizes the array
- *
- *-----------------------------------------------------------------------------
- */
-
-static INLINE Bool
-DynArray_Trim(DynArray *a)    // IN/OUT
-{
-   ASSERT(a);
-
-   return DynBuf_Trim(&a->buf);
-}
-
-
-
-/*
- *-----------------------------------------------------------------------------
- *
- * DynArray_AddressOf --
- *
- *      Fetch a pointer to the address of the ith element.
- *
- * Results:
- *      The pointer to the ith element or NULL if the index is out of
- *      bounds.
- *
- * Side effects:
- *      None
- *
- *-----------------------------------------------------------------------------
- */
-
-static INLINE void *
-DynArray_AddressOf(const DynArray *a,   // IN
-                   unsigned int i)      // IN
-{
-   uintptr_t offset = i * a->width;
-
-   ASSERT(a);
-
-   if (offset + a->width <= DynBuf_GetSize(&a->buf)) {
-      return offset + (uint8 *)DynBuf_Get(&a->buf);
-   }
-
-   return NULL;
-}
-
-
-/*
- *-----------------------------------------------------------------------------
- *
- * DynArray_AddressOfUnsafe --
- *
- *      Fetch a pointer to the address of the ith element. Only call
- *      this if you already know that 'i' is valid. The index is not
- *      checked against the size of the array.
- *
- * Results:
- *      Always returns a pointer to the ith element.
- *
- * Side effects:
- *      None
- *
- *-----------------------------------------------------------------------------
- */
-
-static INLINE void *
-DynArray_AddressOfUnsafe(const DynArray *a,   // IN
-                         unsigned int i)      // IN
-{
-   uintptr_t offset = i * a->width;
-
-   ASSERT(a);
-   ASSERT(offset + a->width <= DynBuf_GetSize(&a->buf));
-
-   return offset + (uint8 *)DynBuf_Get(&a->buf);
-}
-
-
-/*
- *-----------------------------------------------------------------------------
- *
- * DynArray_Count --
- *
- *      Returns the number of elements in the array.
- *
- *      XXX: This is relatively slow, since we do an integer division.
- *           Avoid calling this in inner loops.
- *
- * Results:
- *      See above.
- *
- * Side effects:
- *      None.
- *
- *-----------------------------------------------------------------------------
- */
-
-static INLINE unsigned int
-DynArray_Count(const DynArray *a)       // IN
-{
-   ASSERT(a);
-
-   return (unsigned int) (DynBuf_GetSize(&a->buf) / a->width);
-}
-
-
-/*
- *-----------------------------------------------------------------------------
- *
- * DynArray_Copy --
- *
- *      Copies all data and metadata from src Dynarray to dest DynArray.
- *
- *      Dest should be an initialized DynArray of size zero.
- *
- * Results:
- *      TRUE on success, FALSE on failure.
- *
- * Side effects:
- *      None.
- *
- *-----------------------------------------------------------------------------
- */
-
-static INLINE Bool
-DynArray_Copy(DynArray *src,        // IN
-              DynArray *dest)       // OUT
-{
-   ASSERT(src);
-   ASSERT(dest);
-   ASSERT(dest->width);
-   ASSERT(dest->width == src->width);
-   ASSERT(DynArray_AllocCount(dest) == 0);
-
-   return DynBuf_Copy(&src->buf, &dest->buf);
-}
+void
+DynArray_QSort(DynArray *a, DynArrayCmp compare);
 
+Bool
+DynArray_Copy(DynArray *src, DynArray *dest);
 
 /*
  * Use the following macros to define your own DynArray type to
@@ -256,21 +113,15 @@ DynArray_Copy(DynArray *src,        // IN
 #define DEFINE_DYNARRAY_TYPE(T)     DEFINE_DYNARRAY_NAMED_TYPE(T, T)
 
 #define DEFINE_DYNARRAY_NAMED_TYPE(T, TYPE)                             \
-   DECLARE_DYNARRAY_TYPE(T)                                             \
-   DEFINEONLY_DYNARRAY_NAMED_TYPE(T, TYPE)
-
-#define DECLARE_DYNARRAY_TYPE(T)                                        \
-   typedef DynArray T##Array;
-
-#define DEFINEONLY_DYNARRAY_NAMED_TYPE(T, TYPE)                         \
                                                                         \
    typedef int (CDECLCONV *DynArray##T##Cmp)(const TYPE *,              \
                                              const TYPE *);             \
+   typedef DynArray T##Array;                                           \
                                                                         \
-   static INLINE Bool                                                   \
+   static INLINE void                                                   \
    T##Array_Init(T##Array *a, unsigned int count)                       \
    {                                                                    \
-      return DynArray_Init((DynArray *)a, count, sizeof(TYPE));         \
+      DynArray_Init((DynArray *)a, count, sizeof(TYPE));                \
    }                                                                    \
                                                                         \
    static INLINE void                                                   \
@@ -280,13 +131,13 @@ DynArray_Copy(DynArray *src,        // IN
    }                                                                    \
                                                                         \
    static INLINE TYPE*                                                  \
-   T##Array_AddressOf(T##Array *a, unsigned int i)                      \
+   T##Array_AddressOf(T##Array *a, unsigned int i)                \
    {                                                                    \
       return (TYPE*)DynArray_AddressOf((DynArray *)a, i);               \
    }                                                                    \
                                                                         \
    static INLINE unsigned int                                           \
-   T##Array_Count(T##Array *a)                                          \
+   T##Array_Count(T##Array *a)                                    \
    {                                                                    \
       return DynArray_Count((DynArray *)a);                             \
    }                                                                    \
@@ -309,7 +160,7 @@ DynArray_Copy(DynArray *src,        // IN
    }                                                                    \
                                                                         \
    static INLINE unsigned int                                           \
-   T##Array_AllocCount(T##Array *a)                                     \
+   T##Array_AllocCount(T##Array *a)                               \
    {                                                                    \
       return DynArray_AllocCount((DynArray *)a);                        \
    }                                                                    \
