@@ -335,6 +335,8 @@ Bool    FileIO_GetVolumeSectorSize(const char *name,
 Bool    FileIO_SupportsFileSize(const FileIODescriptor *file,
                                 uint64 testSize);
 
+int64   FileIO_GetModTime(const FileIODescriptor *fd);
+
 FileIOResult FileIO_Lock(FileIODescriptor *file,  // IN/OUT
                          int access);             // IN
 
@@ -368,7 +370,8 @@ int FileIO_PrivilegedPosixOpen(ConstUnicode pathName,
                                int flags);
 #endif
 
-FILE *FileIO_DescriptorToStream(FileIODescriptor *fd);
+FILE *FileIO_DescriptorToStream(FileIODescriptor *fd,
+                                Bool textMode);
 
 ConstUnicode FileIO_Filename(FileIODescriptor *fd);
 
