@@ -48,7 +48,7 @@ typedef enum {
    INFO_DNS_NAME,
    INFO_IPADDRESS,
    INFO_DISK_FREE_SPACE,
-   INFO_TOOLS_VERSION,
+   INFO_BUILD_NUMBER,
    INFO_OS_NAME_FULL,
    INFO_OS_NAME,
    INFO_UPTIME,
