@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 1998-2015 VMware, Inc. All rights reserved.
+ * Copyright (C) 1998-2006 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -28,17 +28,12 @@
 
 #define INCLUDE_ALLOW_USERLEVEL
 #define INCLUDE_ALLOW_VMCORE
-#define INCLUDE_ALLOW_VMKERNEL
 #include "includeCheck.h"
 
 #include "vm_basic_types.h"
 
-Bool HostType_OSIsVMK(void);
-Bool HostType_OSIsSimulator(void);
-
-/* Old name. TODO: remove */
-static INLINE Bool
-HostType_OSIsPureVMK(void)
-{ return HostType_OSIsVMK(); }
+extern Bool HostType_OSIsVMK(void);
+extern Bool HostType_OSIsPureVMK(void);
+extern Bool HostType_OSIsVMK64(void);
 
 #endif /* ifndef _HOSTTYPE_H_ */
