@@ -47,7 +47,7 @@
  * This does not mean it has bsd_vsnwprintf().
  */
 #if defined _WIN32 && !defined STR_NO_WIN32_LIBS || \
-    defined __linux__ && !defined N_PLAT_NLM || __APPLE__
+    defined __linux__ && !defined N_PLAT_NLM || defined __APPLE__
 #define HAS_BSD_PRINTF 1
 #endif
 
