@@ -40,13 +40,14 @@
 struct timeval;
 
 
+/* Similar to a struct tm but with slightly less weird semantics. */
 typedef struct TimeUtil_Date {
-   unsigned int year;
-   unsigned int month;
-   unsigned int day;
-   unsigned int hour;
-   unsigned int minute;
-   unsigned int second;
+   unsigned int year;   /* e.g. 1970 */
+   unsigned int month;  /* [1, 12] */
+   unsigned int day;    /* [1, 31] */
+   unsigned int hour;   /* [0, 23] */
+   unsigned int minute; /* [0, 59] */
+   unsigned int second; /* [0, 61] (for leap seconds) */
 } TimeUtil_Date;
 
 
@@ -75,14 +76,16 @@ typedef struct TimeUtil_Expiration {
 } TimeUtil_Expiration;
 
 
+EXTERN time_t TimeUtil_MakeTime(const TimeUtil_Date *d);
+
 EXTERN Bool TimeUtil_StringToDate(TimeUtil_Date *d,    // IN/OUT
-                                  const char *date);   // IN: 'YYYYMMDD' or 'YYYY/MM/DD' or 'YYYY-MM-DD'
+                                  char const *date);   // IN: 'YYYYMMDD' or 'YYYY/MM/DD' or 'YYYY-MM-DD'
 
-EXTERN Bool TimeUtil_DaysSubstract(TimeUtil_Date *d,  // IN/OUT
-                                   unsigned int nr);  // IN
+EXTERN Bool TimeUtil_DaysSubtract(TimeUtil_Date *d,  // IN/OUT
+                                  unsigned int nr);  // IN
 
-EXTERN int TimeUtil_DeltaDays(TimeUtil_Date *left,   // IN
-                              TimeUtil_Date *right); // IN
+EXTERN int TimeUtil_DeltaDays(TimeUtil_Date const *left,   // IN
+                              TimeUtil_Date const *right); // IN
 
 EXTERN void TimeUtil_DaysAdd(TimeUtil_Date *d, // IN/OUT
                              unsigned int nr); // IN
