@@ -758,6 +758,21 @@ typedef uint32 ToolsVersion;
 #define   TOOLS_VERSION_SERVER20_RC1_V_MNR     7
 #define   TOOLS_VERSION_SERVER20_RC1_V_BASE    2
 
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_SERVER20_RC2       TOOLS_VERSION_TO_UINT(TOOLS_VERSION_SERVER20_RC2_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_SERVER20_RC2_V_MJR     7
+#define   TOOLS_VERSION_SERVER20_RC2_V_MNR     7
+#define   TOOLS_VERSION_SERVER20_RC2_V_BASE    3
+
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_SERVER20_RELEASE       TOOLS_VERSION_TO_UINT(TOOLS_VERSION_SERVER20_RELEASE_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_SERVER20_RELEASE_V_MJR     7
+#define   TOOLS_VERSION_SERVER20_RELEASE_V_MNR     7
+#define   TOOLS_VERSION_SERVER20_RELEASE_V_BASE    4
+
+
 /*
  * XXX: Chromium (WS 6.5) releases should have 7.8.x numbers.
  * We still haven't used that range (beta 1 was released with 7.7.1).
@@ -777,6 +792,27 @@ typedef uint32 ToolsVersion;
 #define   TOOLS_VERSION_WS65_BETA2_V_MNR     8
 #define   TOOLS_VERSION_WS65_BETA2_V_BASE    1
 
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_WS65_RC1     TOOLS_VERSION_TO_UINT(TOOLS_VERSION_WS65_RC1_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_WS65_RC1_V_MJR     7
+#define   TOOLS_VERSION_WS65_RC1_V_MNR     8
+#define   TOOLS_VERSION_WS65_RC1_V_BASE    2
+
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_WS65_RELEASE     TOOLS_VERSION_TO_UINT(TOOLS_VERSION_WS65_RELEASE_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_WS65_RELEASE_V_MJR     7
+#define   TOOLS_VERSION_WS65_RELEASE_V_MNR     8
+#define   TOOLS_VERSION_WS65_RELEASE_V_BASE    3
+
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_WS65_UPDATE1     TOOLS_VERSION_TO_UINT(TOOLS_VERSION_WS65_UPDATE1_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_WS65_UPDATE1_V_MJR     7
+#define   TOOLS_VERSION_WS65_UPDATE1_V_MNR     8
+#define   TOOLS_VERSION_WS65_UPDATE1_V_BASE    4
+
 #ifndef RC_INVOKED
 #define   TOOLS_VERSION_FUSION15_BETA1     TOOLS_VERSION_TO_UINT(TOOLS_VERSION_FUSION15_BETA1_V)
 #endif /* RC_INVOKED */
@@ -798,9 +834,33 @@ typedef uint32 ToolsVersion;
 #define   TOOLS_VERSION_FUSION15_RC1_V_MNR      9
 #define   TOOLS_VERSION_FUSION15_RC1_V_BASE     2
 
-#define   TOOLS_VERSION_CURRENT        TOOLS_VERSION_FUSION15_RC1
-#define   TOOLS_VERSION_CURRENT_STR    TOOLS_VERSION_TO_STR(TOOLS_VERSION_FUSION15_RC1)
-#define   TOOLS_VERSION_CURRENT_CSV    TOOLS_VERSION_TO_CSV(TOOLS_VERSION_FUSION15_RC1)
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_FUSION15_RELEASE    TOOLS_VERSION_TO_UINT(TOOLS_VERSION_FUSION15_RELEASE_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_FUSION15_RELEASE_V_MJR      7
+#define   TOOLS_VERSION_FUSION15_RELEASE_V_MNR      9
+#define   TOOLS_VERSION_FUSION15_RELEASE_V_BASE     3
+
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_FUSION15_UPDATE1    TOOLS_VERSION_TO_UINT(TOOLS_VERSION_FUSION15_UPDATE1_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_FUSION15_UPDATE1_V_MJR      7
+#define   TOOLS_VERSION_FUSION15_UPDATE1_V_MNR      9
+#define   TOOLS_VERSION_FUSION15_UPDATE1_V_BASE     4
+
+/*
+ * At the request of CPD, ESX 4.0 receives its own major version (8.0.0).
+ */
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_ESX40_RC1      TOOLS_VERSION_TO_UINT(TOOLS_VERSION_ESX40_RC1_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_ESX40_RC1_V_MJR      8
+#define   TOOLS_VERSION_ESX40_RC1_V_MNR      0
+#define   TOOLS_VERSION_ESX40_RC1_V_BASE     0
+
+#define   TOOLS_VERSION_CURRENT        TOOLS_VERSION_ESX40_RC1
+#define   TOOLS_VERSION_CURRENT_STR    TOOLS_VERSION_TO_STR(TOOLS_VERSION_ESX40_RC1)
+#define   TOOLS_VERSION_CURRENT_CSV    TOOLS_VERSION_TO_CSV(TOOLS_VERSION_ESX40_RC1)
 
 
 /*
