@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 1998-2015 VMware, Inc. All rights reserved.
+ * Copyright (C) 1998 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -24,7 +24,6 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
 
 #if defined(_WIN32)
 #   include <windows.h>
@@ -33,126 +32,10 @@
 #   include <errno.h>
 #   include <fcntl.h>
 #   include <unistd.h>
-
-#   define GENERIC_RANDOM_DEVICE "/dev/urandom"
 #endif
 
 #include "vmware.h"
-#include "log.h"
 #include "random.h"
-#include "util.h"
-
-
-#if defined(_WIN32)
-/*
- *-----------------------------------------------------------------------------
- *
- * RandomBytesWin32 --
- *
- *      Generate 'size' bytes of cryptographically strong random bits in
- *      'buffer'.
- *
- * Results:
- *      TRUE   success
- *      FALSE  failure
- *
- *-----------------------------------------------------------------------------
- */
-
-static Bool
-RandomBytesWin32(size_t size,   // IN:
-                 void *buffer)  // OUT:
-{
-   HCRYPTPROV csp;
-
-   if (size != (DWORD) size) {
-      Log("%s: Overflow: %"FMTSZ"d\n", __FUNCTION__, size);
-      return FALSE;
-   }
-
-   if (CryptAcquireContext(&csp, NULL, NULL, PROV_RSA_FULL,
-                           CRYPT_VERIFYCONTEXT) == FALSE) {
-      Log("%s: CryptAcquireContext failed: %d\n", __FUNCTION__, GetLastError());
-      return FALSE;
-   }
-
-   if (CryptGenRandom(csp, (DWORD) size, buffer) == FALSE) {
-      Log("%s: CryptGenRandom failed: %d\n", __FUNCTION__, GetLastError());
-      CryptReleaseContext(csp, 0);
-      return FALSE;
-   }
-
-   if (CryptReleaseContext(csp, 0) == FALSE) {
-      Log("%s: CryptReleaseContext failed: %d\n", __FUNCTION__, GetLastError());
-      return FALSE;
-   }
-
-   return TRUE;
-}
-#else
-/*
- *-----------------------------------------------------------------------------
- *
- * RandomBytesPosix --
- *
- *      Generate 'size' bytes of cryptographically strong random bits in
- *      'buffer'.
- *
- * Results:
- *      TRUE   success
- *      FALSE  failure
- *
- *-----------------------------------------------------------------------------
- */
-
-static Bool
-RandomBytesPosix(const char *name,  // IN:
-                 size_t size,       // IN:
-                 void *buffer)      // OUT:
-{
-   int fd = open(name, O_RDONLY);
-
-   if (fd == -1) {
-      Log("%s: failed to open %s: %s\n", __FUNCTION__, name, strerror(errno));
-      return FALSE;
-   }
-
-   /*
-    * Although /dev/urandom does not block, it can return short reads. That
-    * said, reads returning nothing should not happen. Just in case, track
-    * those any that do appear.
-    */
-
-   while (size > 0) {
-      ssize_t bytesRead = read(fd, buffer, size);
-
-      if ((bytesRead == 0) || ((bytesRead == -1) && (errno != EINTR))) {
-         close(fd);
-
-         if (bytesRead == 0) {
-            Log("%s: zero length read while reading from %s\n",
-                __FUNCTION__, name);
-         } else {
-            Log("%s: %"FMTSZ"u byte read failed while reading from %s: %s\n",
-                __FUNCTION__, size, name, strerror(errno));
-         }
-
-         return FALSE;
-      }
-
-      if (bytesRead > 0) {
-         size -= bytesRead;
-         buffer = ((uint8 *) buffer) + bytesRead; 
-      }
-   }
-
-   if (close(fd) == -1) {
-      Log("%s: failed to close %s: %s\n", __FUNCTION__, name, strerror(errno));
-   }
-
-   return TRUE;
-}
-#endif
 
 
 /*
@@ -162,15 +45,12 @@ RandomBytesPosix(const char *name,  // IN:
  *
  *      Generate 'size' bytes of cryptographically strong random bits in
  *      'buffer'. Use this function when you need non-predictable random
- *      bits, typically in security applications, where the bits are generated
- *      external to the application.
- *
- *      DO NOT USE THIS FUNCTION UNLESS YOU HAVE AN ABSOLUTE, EXPLICIT
- *      NEED FOR CRYPTOGRAPHICALLY VALID RANDOM NUMBERS.
+ *      bits, typically in security applications. Use Random_Quick below
+ *      otherwise.
  *
  * Results:
- *      TRUE   success
- *      FALSE  failure
+ *      TRUE on success
+ *      FALSE on failure
  *
  * Side effects:
  *      None
@@ -179,21 +59,71 @@ RandomBytesPosix(const char *name,  // IN:
  */
 
 Bool
-Random_Crypto(size_t size,   // IN:
-              void *buffer)  // OUT:
+Random_Crypto(unsigned int size, // IN
+              void *buffer)      // OUT
 {
 #if defined(_WIN32)
-   return RandomBytesWin32(size, buffer);
+   HCRYPTPROV csp;
+   DWORD error;
+
+   if (CryptAcquireContext(&csp, NULL, NULL, PROV_RSA_FULL,
+                           CRYPT_VERIFYCONTEXT) == FALSE) {
+      error = GetLastError();
+      Log("Random_Crypto: CryptAcquireContext failed %d\n", error);
+      return FALSE;
+   }
+
+   if (CryptGenRandom(csp, size, buffer) == FALSE) {
+      CryptReleaseContext(csp, 0);
+      error = GetLastError();
+      Log("Random_Crypto: CryptGenRandom failed %d\n", error);
+      return FALSE;
+   }
+
+   if (CryptReleaseContext(csp, 0) == FALSE) {
+      error = GetLastError();
+      Log("Random_Crypto: CryptReleaseContext failed %d\n", error);
+      return FALSE;
+   }
 #else
+   int fd;
+   int error;
+
    /*
     * We use /dev/urandom and not /dev/random because it is good enough and
     * because it cannot block. --hpreg
     */
+   fd = open("/dev/urandom", O_RDONLY);
+   if (fd < 0) {
+      error = errno;
+      Log("Random_Crypto: Failed to open: %d\n", error);
+      return FALSE;
+   }
 
-   return RandomBytesPosix(GENERIC_RANDOM_DEVICE, size, buffer);
+   /* Although /dev/urandom does not block, it can return short reads. */
+   while (size > 0) {
+      ssize_t bytesRead = read(fd, buffer, size);
+      if (bytesRead == 0 || (bytesRead == -1 && errno != EINTR)) {
+         error = errno;
+         close(fd);
+         Log("Random_Crypto: Short read: %d\n", error);
+         return FALSE;
+      }
+      if (bytesRead > 0) {
+         size -= bytesRead;
+         buffer = ((uint8 *) buffer) + bytesRead; 
+      }
+   }
+
+   if (close(fd) < 0) {
+      error = errno;
+      Log("Random_Crypto: Failed to close: %d\n", error);
+      return FALSE;
+   }
 #endif
-}
 
+   return TRUE;
+}
 
 
 /*
@@ -210,9 +140,6 @@ Random_Crypto(size_t size,   // IN:
  * Side Effects:
  *      None
  *
- * NOTE:
- *      Despite the look of the code this RNG is extremely fast.
- *
  *-----------------------------------------------------------------------------
  */
 
@@ -226,16 +153,15 @@ Random_Crypto(size_t size,   // IN:
 #define C 0xDB8B0000
 #define L 16
 
-struct rqContext {
+struct rngstate {
   uint32 x[N];
   int p, q;
 };
 
-rqContext *
-Random_QuickSeed(uint32 seed)  // IN:
+void *
+Random_QuickSeed(uint32 seed) // IN:
 {
-   uint32 i;
-   struct rqContext *rs = Util_SafeMalloc(sizeof *rs);
+   struct rngstate *rs;
 
    const uint32 xx[N] = {
       0x95F24DAB, 0x0B685215, 0xE76CCAE7, 0xAF3EC239, 0x715FAD23,
@@ -245,15 +171,20 @@ Random_QuickSeed(uint32 seed)  // IN:
       0x512C0C03, 0xEA857CCD, 0x4CC1D30F, 0x8891A8A1, 0xA6B7AADB
    };
 
+   rs = (struct rngstate *) malloc(sizeof *rs);
 
-   for (i = 0; i < N; i++) {
-      rs->x[i] = xx[i] ^ seed;
+   if (rs != NULL) {
+      uint32 i;
+
+      for (i = 0; i < N; i++) {
+         rs->x[i] = xx[i] ^ seed;
+      }
+
+      rs->p = N - 1;
+      rs->q = N - M - 1;
    }
 
-   rs->p = N - 1;
-   rs->q = N - M - 1;
-
-   return rs;
+   return (void *) rs;
 }
 
 
@@ -273,18 +204,17 @@ Random_QuickSeed(uint32 seed)  // IN:
  * Side Effects:
  *      The RNG context is modified for later use by Random_Quick.
  *
- * NOTE:
- *      Despite the look of the code this RNG is extremely fast.
- *
  *-----------------------------------------------------------------------------
  */
 
 uint32
-Random_Quick(rqContext *rs)  // IN/OUT:
+Random_Quick(void *context)
 {
    uint32 y, z;
 
-   ASSERT(rs);
+   struct rngstate *rs = (struct rngstate *) context;
+
+   ASSERT(context);
 
    if (rs->p == N - 1) {
       rs->p = 0;
@@ -319,36 +249,3 @@ Random_Quick(rqContext *rs)  // IN/OUT:
    return y;
 }
 
-
-/*
- *----------------------------------------------------------------------
- *
- * Random_Simple --
- *
- *      Generates the next random number in the pseudo-random sequence
- *      defined by the multiplicative linear congruential generator
- *      S' = 33614 * S mod (2^31 - 1).  This is the ACM "minimal standard
- *      random number generator". Based on method described by D.G. Carta
- *      in CACM, January 1990.
- *
- *      Usage: provide previous random number as the seed for next one.
- *
- * Results:
- *      A random integer number is returned.
- *
- * Side Effects:
- *      None.
- *
- *----------------------------------------------------------------------
- */
-
-int
-Random_Simple(int seed)  // IN:
-{
-   uint64 product    = 33614 * (uint64) seed;
-   uint32 product_lo = (uint32) (product & 0xFFFFFFFF) >> 1;
-   uint32 product_hi = product >> 32;
-   int32  test       = product_lo + product_hi;
-
-   return test > 0 ? test : (test & 0x7FFFFFFF) + 1;
-}
