@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 1998-2015 VMware, Inc. All rights reserved.
+ * Copyright (C) 1998 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -26,15 +26,13 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#if !defined(_WIN32)
+#if !defined(_WIN32) && !defined(N_PLAT_NLM)
 #include <strings.h> /* For strncasecmp */
 #endif
 #include "vmware.h"
 #include "strutil.h"
 #include "str.h"
-#include "dynbuf.h"
-#include "vm_ctype.h"
-#include "util.h"
+
 
 
 /*
@@ -95,7 +93,8 @@ StrUtil_GetNextToken(unsigned int *index,    // IN/OUT: Index to start at
 
    length = *index - startIndex;
    ASSERT(length);
-   token = Util_SafeMalloc(length + 1 /* NUL */);
+   token = (char *)malloc(length + 1 /* NUL */);
+   ASSERT_MEM_ALLOC(token);
    memcpy(token, str + startIndex, length);
    token[length] = '\0';
 
@@ -266,7 +265,7 @@ StrUtil_DecimalStrToUint(unsigned int *out, // OUT
    *out = (unsigned int)val;
    return TRUE;
 }
-
+   
 
 /*
  *-----------------------------------------------------------------------------
@@ -300,14 +299,11 @@ StrUtil_StrToInt(int32 *out,      // OUT
 
    val = strtol(str, &ptr, 0);
    *out = (int32)val;
-
    /*
-    * Input must be complete, no overflow, and value read must fit into
-    * 32 bits - both signed and unsigned values are accepted.
+    * Input must be complete, no overflow, and value read must fit into 32 bits -
+    * both signed and unsigned values are accepted.
     */
-
-   return *ptr == '\0' && errno != ERANGE &&
-          (val == (int32)val || val == (uint32)val);
+   return *ptr == '\0' && errno != ERANGE && (val == (int32)val || val == (uint32)val);
 }
 
 
@@ -342,14 +338,11 @@ StrUtil_StrToUint(uint32 *out,     // OUT
 
    val = strtoul(str, &ptr, 0);
    *out = (uint32)val;
-
    /*
-    * Input must be complete, no overflow, and value read must fit into 32
-    * bits - both signed and unsigned values are accepted.
+    * Input must be complete, no overflow, and value read must fit into 32 bits -
+    * both signed and unsigned values are accepted.
     */
-
-   return *ptr == '\0' && errno != ERANGE &&
-          (val == (uint32)val || val == (int32)val);
+   return *ptr == '\0' && errno != ERANGE && (val == (uint32)val || val == (int32)val);
 }
 
 
@@ -385,6 +378,9 @@ StrUtil_StrToInt64(int64 *out,      // OUT: The output value
    *out = _strtoi64(str, &ptr, 0);
 #elif defined(__FreeBSD__)
    *out = strtoq(str, &ptr, 0);
+#elif defined(N_PLAT_NLM)
+   /* Works for small values of str... */
+   *out = (int64)strtol(str, &ptr, 0);
 #else
    *out = strtoll(str, &ptr, 0);
 #endif
@@ -393,46 +389,6 @@ StrUtil_StrToInt64(int64 *out,      // OUT: The output value
 }
 
 
-/*
- *-----------------------------------------------------------------------------
- *
- * StrUtil_StrToUint64 --
- *
- *      Convert a string into an unsigned 64bit integer.
- *
- * Results:
- *      TRUE if conversion was successful, FALSE otherwise.
- *      Value is stored in 'out', which is left undefined in the FALSE case.
- *
- * Side effects:
- *      None
- *
- *-----------------------------------------------------------------------------
- */
-
-Bool
-StrUtil_StrToUint64(uint64 *out,     // OUT: The output value
-                    const char *str) // IN : String to parse
-{
-   char *ptr;
-
-   ASSERT(out);
-   ASSERT(str);
-
-   errno = 0;
-
-#if defined(_WIN32)
-   *out = _strtoui64(str, &ptr, 0);
-#elif defined(__FreeBSD__)
-   *out = strtouq(str, &ptr, 0);
-#else
-   *out = strtoull(str, &ptr, 0);
-#endif
-
-   return ptr[0] == '\0' && errno != ERANGE && errno != EINVAL;
-}
-
-
 /*
  *-----------------------------------------------------------------------------
  *
@@ -461,12 +417,15 @@ StrUtil_StrToSizet(size_t *out,     // OUT: The output value
    ASSERT(str);
 
    errno = 0;
-#if defined VM_64BIT
+#if defined VM_X86_64
    ASSERT_ON_COMPILE(sizeof *out == sizeof(uint64));
 #   if defined(_WIN32)
    *out = _strtoui64(str, &ptr, 0);
 #   elif defined(__FreeBSD__)
    *out = strtouq(str, &ptr, 0);
+#   elif defined(N_PLAT_NLM)
+   /* Works for small values of str... */
+   *out = strtoul(str, &ptr, 0);
 #   else
    *out = strtoull(str, &ptr, 0);
 #   endif
@@ -479,181 +438,6 @@ StrUtil_StrToSizet(size_t *out,     // OUT: The output value
 }
 
 
-/*
- *-----------------------------------------------------------------------------
- *
- * StrUtil_StrToDouble --
- *
- *      Convert a string into a double.
- *
- * Results:
- *      TRUE if the conversion was successful and 'out' contains the converted
- *      result.
- *      FALSE otherwise. 'out' is undefined.
- *
- * Side effects:
- *      Modifies errno.
- *
- *-----------------------------------------------------------------------------
- */
-
-Bool
-StrUtil_StrToDouble(double *out,      // OUT: The output value
-                    const char *str)  // IN : String to parse
-{
-   char *ptr = NULL;
-
-   ASSERT(out);
-   ASSERT(str);
-
-   errno = 0;
-
-   *out = strtod(str, &ptr);
-
-   /*
-    * Input must be complete and no overflow.
-    */
-
-   return *ptr == '\0' && errno != ERANGE;
-}
-
-
-/*
- *-----------------------------------------------------------------------------
- *
- * StrUtil_CapacityToBytes --
- *
- *      Converts a string containing a measure of capacity (such as
- *      "100MB" or "1.5k") into an unadorned and primitive quantity of bytes
- *      capacity. The comment before the switch statement describes the kinds
- *      of capacity expressible.
- *
- * Results:
- *      TRUE if conversion was successful, FALSE otherwise.
- *      Value is stored in 'out', which is left undefined in the FALSE case.
- *
- * Side effects:
- *      None
- *
- *-----------------------------------------------------------------------------
- */
-
-Bool
-StrUtil_CapacityToBytes(uint64 *out,        // OUT: The output value
-                        const char *str,    // IN: String to parse
-                        unsigned int bytes) // IN: Bytes per unit in an
-                                            //     unadorned string
-
-{
-   double quantity;
-   char *rest;
-
-   ASSERT(out);
-   ASSERT(str);
-
-   errno = 0;
-   quantity = strtod(str, &rest);
-   if (errno == ERANGE) {
-      return FALSE;
-   }
-
-   /* Skip over any whitespace in the suffix. */
-   while (*rest == ' ' || *rest == '\t') {
-      rest++;
-   }
-   if (*rest != '\0') {
-      uint64 shift;
-      Bool suffixOK = TRUE;
-
-      /*
-       * [kK], [mM], [gG], and [tT] represent kilo, mega, giga, and tera
-       * byte quantities respectively. [bB] represents a singular byte
-       * quantity. [sS] represents a sector quantity.
-       *
-       * For kilo, mega, giga, and tera we're OK with an additional byte
-       * suffix. Otherwise, the presence of an additional suffix is an error.
-       */
-      switch (*rest) {
-      case 'b': case 'B': shift = 0;  suffixOK = FALSE; break;
-      case 's': case 'S': shift = 9;  suffixOK = FALSE; break;
-      case 'k': case 'K': shift = 10;                   break;
-      case 'm': case 'M': shift = 20;                   break;
-      case 'g': case 'G': shift = 30;                   break;
-      case 't': case 'T': shift = 40;                   break;
-      default :                                         return FALSE;
-      }
-      switch(*++rest) {
-      case '\0':
-         break;
-      case 'b': case 'B':
-         if (suffixOK && !*++rest) {
-            break;
-         }
-         /* FALLTHRU */
-      default:
-         return FALSE;
-      }
-      quantity *= CONST64U(1) << shift;
-   } else {
-      /*
-       * No suffix, so multiply by the number of bytes per unit as specified
-       * by the caller.
-       */
-      quantity *= bytes;
-   }
-
-   *out = quantity;
-
-   return TRUE;
-}
-
-
-/*
- *-----------------------------------------------------------------------------
- *
- * StrUtil_CapacityToSectorType --
- *
- *      Converts a string containing a measure of disk capacity (such as
- *      "100MB" or "1.5k") into an unadorned and primitive quantity of sector
- *      capacity.
- *
- * Results:
- *      TRUE if conversion was successful, FALSE otherwise.
- *      Value is stored in 'out', which is left undefined in the FALSE case.
- *
- * Side effects:
- *      None
- *
- *-----------------------------------------------------------------------------
- */
-
-Bool
-StrUtil_CapacityToSectorType(SectorType *out,    // OUT: The output value
-                             const char *str,    // IN: String to parse
-                             unsigned int bytes) // IN: Bytes per unit in an
-                                                 //     unadorned string
-
-{
-   uint64 quantityInBytes;
-
-   if (StrUtil_CapacityToBytes(&quantityInBytes, str, bytes) == FALSE) {
-      return FALSE;
-   }
- 
-   /*
-    * Convert from "number of bytes" to "number of sectors", rounding up or
-    * down appropriately.
-    *
-    * XXX: We should use DISKLIB_SECTOR_SIZE, but do we really want the
-    * disklib header dependencies in this file?
-    *
-    */
-   *out = (SectorType)((quantityInBytes + 256) / 512);
-
-   return TRUE;
-}
-
-
 /*
  *-----------------------------------------------------------------------------
  *
@@ -678,10 +462,9 @@ StrUtil_FormatSizeInBytesUnlocalized(uint64 size) // IN
    /*
     * XXX TODO, BUG 199661:
     * This is a direct copy of Msg_FormatSizeInBytes without localization.
-    * These two functions should ideally share the basic functionality, and
-    * just differ in the string localization
+    * These two functions should ideally share the basic functionality, and just
+    * differ in the string localization
     */
-
    char const *fmt;
    double sizeInSelectedUnit;
    unsigned int precision;
@@ -796,7 +579,6 @@ StrUtil_GetLongestLineLength(const char *buf,   //IN
        bufLength -= len;
        buf = next;
     }
-
     return longest;
 }
 
@@ -823,13 +605,7 @@ StrUtil_StartsWith(const char *s,      // IN
 {
    ASSERT(s != NULL);
    ASSERT(prefix != NULL);
-
-   while (*prefix && *prefix == *s) {
-      prefix++;
-      s++;
-   }
-
-   return *prefix == '\0';
+   return Str_Strncmp(s, prefix, strlen(prefix)) == 0;
 }
 
 
@@ -855,7 +631,6 @@ StrUtil_CaselessStartsWith(const char *s,      // IN
 {
    ASSERT(s != NULL);
    ASSERT(prefix != NULL);
-
    return Str_Strncasecmp(s, prefix, strlen(prefix)) == 0;
 }
 
@@ -868,8 +643,7 @@ StrUtil_CaselessStartsWith(const char *s,      // IN
  *      Detects if a string ends with another string.
  *
  * Results:
- *      TRUE  if string 'suffix' is found at the end of string 's'
- *      FALSE otherwise.
+ *      TRUE if string 'suffix' is found at the end of string 's', FALSE otherwise.
  *
  * Side effects:
  *      None.
@@ -898,37 +672,6 @@ StrUtil_EndsWith(const char *s,      // IN
 }
 
 
-/*
- *-----------------------------------------------------------------------------
- *
- * StrUtil_IsASCII --
- *
- * Results:
- *      Returns TRUE if the string contains only ASCII characters, FALSE
- *      otherwise.
- *
- * Side effects:
- *      None.
- *
- *-----------------------------------------------------------------------------
- */
-
-Bool
-StrUtil_IsASCII(const char *s) // IN
-{
-   ASSERT(s != NULL);
-
-   while (*s != '\0') {
-      if (!CType_IsAscii(*s)) {
-         return FALSE;
-      }
-      s++;
-   }
-
-   return TRUE;
-}
-
-
 /*
  *-----------------------------------------------------------------------------
  *
@@ -960,7 +703,6 @@ StrUtil_VDynBufPrintf(DynBuf *b,        // IN/OUT
     * Arbitrary lower-limit on buffer size allocation, to avoid doing
     * many tiny enlarge operations.
     */
-
    const size_t minAllocSize = 128;
 
    while (1) {
@@ -978,18 +720,18 @@ StrUtil_VDynBufPrintf(DynBuf *b,        // IN/OUT
       }
 
       /*
-       * Is there any allocated-but-not-occupied space? If so, try the printf.
-       * If there was no space to begin with, or Str_Vsnprintf() ran out of
-       * space, this will fail.
+       * Is there any allocated-but-not-occupied space? If so,
+       * try the printf. If there was no space to begin with, or
+       * Str_Vsnprintf() ran out of space, this will fail.
+       *
+       * Note that we don't need to copy the argument list, it's
+       * okay to iterate over the same va_list multiple times.
+       * Str_Vsnprintf() already does a va_copy on platforms that
+       * need it.
        */
 
       if (allocSize - size > 0) {
-         va_list tmpArgs;
-
-         va_copy(tmpArgs, args);
-         i = Str_Vsnprintf((char *) DynBuf_Get(b) + size, allocSize - size,
-                           fmt, tmpArgs);
-         va_end(tmpArgs);
+         i = Str_Vsnprintf((char*)DynBuf_Get(b) + size, allocSize - size, fmt, args);
       } else {
          i = -1;
       }
@@ -1003,9 +745,7 @@ StrUtil_VDynBufPrintf(DynBuf *b,        // IN/OUT
           * happens, believe it or not. See bug 253674.
           */
 
-         ASSERT(i + size == allocSize ||
-                ((char *)DynBuf_Get(b))[i + size] == '\0');
-
+         ASSERT(i + size == allocSize || ((char*)DynBuf_Get(b))[i + size] == '\0');
          DynBuf_SetSize(b, size + i);
          break;
 
@@ -1017,7 +757,6 @@ StrUtil_VDynBufPrintf(DynBuf *b,        // IN/OUT
           */
 
          Bool success = DynBuf_Enlarge(b, size + minAllocSize);
-
          if (!success) {
             return FALSE;
          }
@@ -1089,149 +828,5 @@ StrUtil_SafeDynBufPrintf(DynBuf *b,        // IN/OUT
    success = StrUtil_VDynBufPrintf(b, fmt, args);
    va_end(args);
 
-   VERIFY(success);
-}
-
-
-/*
- *-----------------------------------------------------------------------------
- *
- * StrUtil_SafeStrcat --
- *
- *      Given an input buffer, append another string and return the resulting
- *      string. The input buffer is freed along the way. A fancy strcat().
- *
- * Results:
- *      New buffer returned via 'prefix'
- *
- * Side effects:
- *      None.
- *
- *-----------------------------------------------------------------------------
- */
-
-void
-StrUtil_SafeStrcat(char **prefix,    // IN/OUT
-                   const char *str)  // IN
-{
-   char *tmp;
-   size_t plen = *prefix != NULL ? strlen(*prefix) : 0;
-   size_t slen = strlen(str);
-
-   /* Check for overflow */
-   VERIFY((size_t)-1 - plen > slen + 1);
-
-   tmp = Util_SafeRealloc(*prefix, plen + slen + 1 /* NUL */);
-
-   memcpy(tmp + plen, str, slen + 1 /* NUL */);
-   *prefix = tmp;
-}
-
-
-/*
- *-----------------------------------------------------------------------------
- *
- * StrUtil_SafeStrcatFV --
- *
- *      Given an input buffer, append another string and return the resulting
- *      string. The input buffer is freed along the way. A fancy vasprintf().
- *
- * Results:
- *      New buffer returned via 'prefix'
- *
- * Side effects:
- *      None.
- *
- *-----------------------------------------------------------------------------
- */
-
-void
-StrUtil_SafeStrcatFV(char **prefix,    // IN/OUT
-                     const char *fmt,  // IN
-                     va_list args)     // IN
-{
-   char *str = Str_SafeVasprintf(NULL, fmt, args);
-   StrUtil_SafeStrcat(prefix, str);
-   free(str);
-}
-
-
-/*
- *-----------------------------------------------------------------------------
- *
- * StrUtil_SafeStrcatF --
- *
- *      Given an input buffer, append another string and return the resulting
- *      string. The input buffer is freed along the way. A fancy asprintf().
- *
- * Results:
- *      New buffer returned via 'prefix'
- *
- * Side effects:
- *      None.
- *
- *-----------------------------------------------------------------------------
- */
-
-void
-StrUtil_SafeStrcatF(char **prefix,    // IN/OUT
-                    const char *fmt,  // IN
-                    ...)              // IN
-{
-   va_list args;
-
-   va_start(args, fmt);
-   StrUtil_SafeStrcatFV(prefix, fmt, args);
-   va_end(args);
-}
-
-
-/*
- *-----------------------------------------------------------------------------
- *
- * StrUtil_TrimWhitespace --
- *
- *      Return a copy of the input string with leading and trailing
- *      whitespace removed.
- *
- * Results:
- *      See above. Caller should free with free().
- *
- * Side effects:
- *      None.
- *
- *-----------------------------------------------------------------------------
- */
-
-char *
-StrUtil_TrimWhitespace(const char *str)  // IN
-{
-   char *cur = (char *)str;
-   char *res = NULL;
-   size_t len;
-
-   /* Skip leading whitespace. */
-   while (*cur && isspace(*cur)) {
-      cur++;
-   }
-
-   /* Copy the remaining string. */
-   res = Util_SafeStrdup(cur);
-
-   /* Find the beginning of the trailing whitespace. */
-   len = strlen(res);
-   if (len == 0) {
-      return res;
-   }
-
-   cur = res + len - 1;
-   while (cur > res && isspace(*cur)) {
-      cur--;
-   }
-
-   /* Truncate it. */
-   cur++;
-   *cur = 0;
-
-   return res;
+   ASSERT_MEM_ALLOC(success);
 }
