@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 2008-2015 VMware, Inc. All rights reserved.
+ * Copyright (C) 2008 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -23,8 +23,6 @@
  *
  */
 
-#include <string.h>
-
 #include "vm_assert.h"
 #include "config.h"
 #include "preference.h"
@@ -48,27 +46,13 @@ Config_GetLong(int32 defaultValue,
 }
 
 
-double
-Config_GetDouble(double defaultValue,
-                 const char *fmt,
-                 ...)
-{
-   return defaultValue;
-}
-
-
 char *
 Config_GetString(const char *defaultValue,
                  const char *fmt, ...)
 {
-   return (defaultValue == NULL) ? NULL : strdup(defaultValue);
+   return (char *) defaultValue;
 }
 
-Bool
-Preference_Init(void)
-{
-   return TRUE;
-}
 
 Bool
 Preference_GetBool(Bool defaultValue,
@@ -82,7 +66,7 @@ char *
 Preference_GetString(const char *defaultValue,
                      const char *name)
 {
-   return (defaultValue == NULL) ? NULL : strdup(defaultValue);
+   return (char *) defaultValue;
 }
 
 
@@ -90,25 +74,6 @@ char *
 Preference_GetPathName(const char *defaultValue,
                        const char *fmt)
 {
-   return (defaultValue == NULL) ? NULL : strdup(defaultValue);
+   return (char *) defaultValue;
 }
 
-int32
-Config_GetTriState(int32 defaultValue,
-                   const char *fmt, ...)
-{
-   return defaultValue;
-}
-
-char *
-Config_GetPathName(const char *defaultValue,
-                   const char *format, ...)
-{
-   return defaultValue ? strdup(defaultValue) : NULL;
-}
-
-Bool
-Config_NotSet(const char *fmt, ...)
-{
-   return FALSE;
-}
