@@ -79,7 +79,7 @@
 #define BDOOR_CMD_GETUUID               19
 #define BDOOR_CMD_GETMEMSIZE            20
 #define BDOOR_CMD_HOSTCOPY              21 /* Devel only */
-/* BDOOR_CMD_GETOS2INTCURSOR, 22, is very old and defunct. Reuse. */
+#define BDOOR_CMD_SERVICE_VM            22 /* prototype only */         
 #define BDOOR_CMD_GETTIME               23 /* Deprecated. Use GETTIMEFULL. */
 #define BDOOR_CMD_STOPCATCHUP           24
 #define BDOOR_CMD_PUTCHR	        25 /* Devel only */
@@ -93,7 +93,7 @@
 #define BDOOR_CMD_RSVD2                 33
 #define BDOOR_CMD_ISACPIDISABLED	34
 #define BDOOR_CMD_TOE			35 /* Not in use */
-/* BDOOR_CMD_INITLSIOPROM, 36, was merged with 28. Reuse. */
+#define BDOOR_CMD_ISMOUSEABSOLUTE       36
 #define BDOOR_CMD_PATCH_SMBIOS_STRUCTS  37
 #define BDOOR_CMD_MAPMEM                38 /* Devel only */
 #define BDOOR_CMD_ABSPOINTER_DATA	39
@@ -113,7 +113,9 @@
 #define BDOOR_CMD_ISGOSDARWIN           52
 #define BDOOR_CMD_DEBUGEVENT            53
 #define BDOOR_CMD_OSNOTMACOSXSERVER     54
-#define BDOOR_CMD_MAX                   55
+#define BDOOR_CMD_GETTIMEFULL_WITH_LAG  55
+#define BDOOR_CMD_ACPI_HOTPLUG          56
+#define BDOOR_CMD_MAX                   57
 
 /* 
  * IMPORTANT NOTE: When modifying the behavior of an existing backdoor command,
