@@ -20,8 +20,6 @@
  * vm_basic_asm.h
  *
  *	Basic asm macros
- *
- *        ARM not implemented.
  */
 
 #ifndef _VM_BASIC_ASM_H_
@@ -42,9 +40,9 @@
 #include "vm_basic_types.h"
 #include "x86cpuid.h"
 
-#if defined VM_X86_64
+#ifdef VM_X86_64
 #include "vm_basic_asm_x86_64.h"
-#elif defined __i386__
+#else
 #include "vm_basic_asm_x86.h"
 #endif
 
@@ -110,7 +108,6 @@ void           _mm_pause(void);
 
 
 #ifdef __GNUC__ // {
-#if defined(__i386__) || defined(__x86_64__) // Only on x86*
 
 /*
  * Checked against the Intel manual and GCC --hpreg
@@ -174,42 +171,20 @@ __GCC_IN(l, uint32, IN32)
  *
  */
 
-/*
- * %ebx is reserved on i386 PIC.  Apple's gcc-5493 (gcc 4.0) compiling
- * for x86_64 incorrectly errors out saying %ebx is reserved.  This is
- * Apple bug 7304232.
- */
-#if vm_x86_64 ? (defined __APPLE_CC__ && __APPLE_CC__ == 5493) : defined __PIC__
-#if vm_x86_64
-/*
- * Note that this generates movq %rbx,%rbx; cpuid; xchgq %rbx,%rbx ...
- * Unfortunately Apple's assembler does not have .ifnes, and I cannot
- * figure out how to do that with .if.   If we ever enable this code
- * on other 64bit systems, both movq & xchgq should be surrounded by
- * .ifnes \"%%rbx\", \"%q1\" & .endif
- */
-#define VM_CPUID_BLOCK  "movq %%rbx, %q1\n\t" \
-                        "cpuid\n\t"           \
-                        "xchgq %%rbx, %q1\n\t"
-#define VM_EBX_OUT(reg) "=&r"(reg)
-#else
-#define VM_CPUID_BLOCK  "movl %%ebx, %1\n\t" \
-                        "cpuid\n\t"          \
-                        "xchgl %%ebx, %1\n\t"
-#define VM_EBX_OUT(reg) "=&rm"(reg)
-#endif
-#else
-#define VM_CPUID_BLOCK  "cpuid"
-#define VM_EBX_OUT(reg) "=b"(reg)
-#endif
-
 static INLINE void
 __GET_CPUID(int eax,         // IN
             CPUIDRegs *regs) // OUT
 {
    __asm__ __volatile__(
-      VM_CPUID_BLOCK
-      : "=a" (regs->eax), VM_EBX_OUT(regs->ebx), "=c" (regs->ecx), "=d" (regs->edx)
+#if defined __PIC__ && !vm_x86_64 // %ebx is reserved by the compiler.
+      "movl %%ebx, %1"  "\n\t"
+      "cpuid"           "\n\t"
+      "xchgl %%ebx, %1"
+      : "=a" (regs->eax), "=&rm" (regs->ebx), "=c" (regs->ecx), "=d" (regs->edx)
+#else
+      "cpuid"
+      : "=a" (regs->eax), "=b" (regs->ebx), "=c" (regs->ecx), "=d" (regs->edx)
+#endif
       : "a" (eax)
       : "memory"
    );
@@ -221,8 +196,15 @@ __GET_CPUID2(int eax,         // IN
              CPUIDRegs *regs) // OUT
 {
    __asm__ __volatile__(
-      VM_CPUID_BLOCK
-      : "=a" (regs->eax), VM_EBX_OUT(regs->ebx), "=c" (regs->ecx), "=d" (regs->edx)
+#if defined __PIC__ && !vm_x86_64 // %ebx is reserved by the compiler.
+      "movl %%ebx, %1"  "\n\t"
+      "cpuid"           "\n\t"
+      "xchgl %%ebx, %1"
+      : "=a" (regs->eax), "=&rm" (regs->ebx), "=c" (regs->ecx), "=d" (regs->edx)
+#else
+      "cpuid"
+      : "=a" (regs->eax), "=b" (regs->ebx), "=c" (regs->ecx), "=d" (regs->edx)
+#endif
       : "a" (eax), "c" (ecx)
       : "memory"
    );
@@ -231,14 +213,25 @@ __GET_CPUID2(int eax,         // IN
 static INLINE uint32
 __GET_EAX_FROM_CPUID(int eax) // IN
 {
+#if defined __PIC__ && !vm_x86_64 // %ebx is reserved by the compiler.
    uint32 ebx;
 
    __asm__ __volatile__(
-      VM_CPUID_BLOCK
-      : "=a" (eax), VM_EBX_OUT(ebx)
+      "movl %%ebx, %1"  "\n\t"
+      "cpuid"           "\n\t"
+      "xchgl %%ebx, %1"
+      : "=a" (eax), "=&rm" (ebx)
       : "a" (eax)
       : "memory", "%ecx", "%edx"
    );
+#else
+   __asm__ __volatile__(
+      "cpuid"
+      : "=a" (eax)
+      : "a" (eax)
+      : "memory", "%ebx", "%ecx", "%edx"
+   );
+#endif
 
    return eax;
 }
@@ -249,8 +242,15 @@ __GET_EBX_FROM_CPUID(int eax) // IN
    uint32 ebx;
 
    __asm__ __volatile__(
-      VM_CPUID_BLOCK
-      : "=a" (eax), VM_EBX_OUT(ebx)
+#if defined __PIC__ && !vm_x86_64 // %ebx is reserved by the compiler.
+      "movl %%ebx, %1"  "\n\t"
+      "cpuid"           "\n\t"
+      "xchgl %%ebx, %1"
+      : "=a" (eax), "=&rm" (ebx)
+#else
+      "cpuid"
+      : "=a" (eax), "=b" (ebx)
+#endif
       : "a" (eax)
       : "memory", "%ecx", "%edx"
    );
@@ -262,14 +262,26 @@ static INLINE uint32
 __GET_ECX_FROM_CPUID(int eax) // IN
 {
    uint32 ecx;
+#if defined __PIC__ && !vm_x86_64 // %ebx is reserved by the compiler.
    uint32 ebx;
 
    __asm__ __volatile__(
-      VM_CPUID_BLOCK
-      : "=a" (eax), VM_EBX_OUT(ebx), "=c" (ecx)
+      "movl %%ebx, %1"  "\n\t"
+      "cpuid"           "\n\t"
+      "xchgl %%ebx, %1"
+      : "=a" (eax), "=&rm" (ebx), "=c" (ecx)
       : "a" (eax)
       : "memory", "%edx"
    );
+#else
+
+   __asm__ __volatile__(
+      "cpuid"
+      : "=a" (eax), "=c" (ecx)
+      : "a" (eax)
+      : "memory", "%ebx", "%edx"
+   );
+#endif
 
    return ecx;
 }
@@ -278,14 +290,26 @@ static INLINE uint32
 __GET_EDX_FROM_CPUID(int eax) // IN
 {
    uint32 edx;
+#if defined __PIC__ && !vm_x86_64 // %ebx is reserved by the compiler.
    uint32 ebx;
 
    __asm__ __volatile__(
-      VM_CPUID_BLOCK
-      : "=a" (eax), VM_EBX_OUT(ebx), "=d" (edx)
+      "movl %%ebx, %1"  "\n\t"
+      "cpuid"           "\n\t"
+      "xchgl %%ebx, %1"
+      : "=a" (eax), "=&rm" (ebx), "=d" (edx)
       : "a" (eax)
       : "memory", "%ecx"
    );
+#else
+
+   __asm__ __volatile__(
+      "cpuid"
+      : "=a" (eax), "=d" (edx)
+      : "a" (eax)
+      : "memory", "%ebx", "%ecx"
+   );
+#endif
 
    return edx;
 }
@@ -295,26 +319,33 @@ static INLINE uint32
 __GET_EAX_FROM_CPUID4(int ecx) // IN
 {
    uint32 eax;
+#if defined __PIC__ && !vm_x86_64 // %ebx is reserved by the compiler.
    uint32 ebx;
 
    __asm__ __volatile__(
-      VM_CPUID_BLOCK
-      : "=a" (eax), VM_EBX_OUT(ebx), "=c" (ecx)
+      "movl %%ebx, %1"  "\n\t"
+      "cpuid"           "\n\t"
+      "xchgl %%ebx, %1"
+      : "=a" (eax), "=&rm" (ebx), "=c" (ecx)
       : "a" (4), "c" (ecx)
       : "memory", "%edx"
    );
+#else
+
+   __asm__ __volatile__(
+      "cpuid"
+      : "=a" (eax), "=c" (ecx)
+      : "a" (4), "c" (ecx)
+      : "memory", "%ebx", "%edx"
+   );
+#endif
 
    return eax;
 }
 
-#undef VM_CPUID_BLOCK
-#undef VM_EBX_OUT
-
-#endif // x86*
-
 #elif defined(_MSC_VER) // } {
 static INLINE  uint8
-INB(uint16 port)
+INB(uint16 port) 
 {
    return (uint8)_inp(port);
 }
@@ -334,11 +365,11 @@ OUTW(uint16 port, uint16 value)
    _outpw(port, value);
 }
 static INLINE  uint32
-IN32(uint16 port)
+IN32(uint16 port) 
 {
    return _inpd(port);
 }
-static INLINE void
+static INLINE void 
 OUT32(uint16 port, uint32 value)
 {
    _outpd(port, value);
@@ -822,21 +853,4 @@ RDTSC(void)
 #error No compiler defined for RDTSC
 #endif /* __GNUC__  */
 
-/*
- *-----------------------------------------------------------------------------
- *
- * DEBUGBREAK --
- *
- *    Does an int3 for MSVC / GCC. This is a macro to make sure int3 is
- *    always inlined.
- *
- *-----------------------------------------------------------------------------
- */
-
-#ifdef _MSC_VER
-#define DEBUGBREAK()   __debugbreak()
-#else
-#define DEBUGBREAK()   __asm__ (" int $3 ")
-#endif
-
 #endif
