@@ -36,9 +36,6 @@
 
 #include "vm_basic_defs.h"  // for offsetof()
 
-#define SCSI_MIN_CMD_LEN   6
-#define SCSI_MAX_CMD_LEN   16
-
 /*
  * Non-exhaustive list of SCSI operation codes.  Note that
  * some codes are defined differently according to the target
@@ -210,7 +207,6 @@
 #define SCSI_SENSE_KEY_UNIT_ATTENTION  0x6   // the LUN has been reset (bus reset of medium change)
 #define SCSI_SENSE_KEY_DATA_PROTECT    0x7   // access to the data is blocked
 #define SCSI_SENSE_KEY_BLANK_CHECK     0x8   // reached an unexpected written or unwritten region of the medium
-#define SCSI_SENSE_KEY_VENDOR_SPECIFIC 0x9   // report vendor specific condition
 #define SCSI_SENSE_KEY_COPY_ABORTED    0xa   // COPY, COMPARE, or COPY AND VERIFY was aborted
 #define SCSI_SENSE_KEY_ABORTED_CMD     0xb   // the target aborted the command
 #define SCSI_SENSE_KEY_EQUAL	       0xc   // comparison for SEARCH DATA was unsuccessful
@@ -239,7 +235,6 @@
 #define SCSI_ASC_UNRECOVERED_READ_ERROR                         0x11  // Unrecovered read error
 #define SCSI_ASC_PARAM_LIST_LENGTH_ERROR                        0x1a  // parameter list length error
 #define SCSI_ASC_INVALID_COMMAND_OPERATION      		0x20  // invalid command operation code
-#define SCSI_ASC_LOGICAL_BLOCK_ADDRESS_OUT_OF_RANGE             0x21  // Invalid LBA
 #define SCSI_ASC_INVALID_FIELD_IN_CDB                           0x24
 #define SCSI_ASC_LU_NOT_SUPPORTED                               0x25  // LU has been removed
 #define SCSI_ASC_INVALID_FIELD_IN_PARAMETER_LIST                0x26
@@ -284,12 +279,11 @@
  * We do not support 16-byte CDB's, only 6-, 10-, and 12-byte versions.
  */
 typedef struct {
-   uint8    opcode;     // operation code
-   uint8    lbnhi:5,    // top 5 bits of logical block number
-            lun:3;      // logical unit number
-   uint16   lbnlo;      // bottom 16 bits of logical block number
-   uint8    length;     // data length
-   uint8    control;    // control byte
+   uint32   opcode:8,	// operation code
+	    lun:3,	// logical unit number
+	    lbn:21;	// logical block number
+   uint8    len;	// data length
+   uint8    ctrl;	// control byte
 } SCSICDB6;
 typedef
 #include "vmware_pack_begin.h"
@@ -299,8 +293,8 @@ struct {
 	    lun:3;
    uint32   lbn;
    uint8    reserved;
-   uint16   length;
-   uint8    control;
+   uint16   len;
+   uint8    ctrl;
 }
 #include "vmware_pack_end.h"
 SCSICDB10;
@@ -311,9 +305,9 @@ struct {
    uint8       :5,
 	    lun:3;
    uint32   lbn;
-   uint32   length;
+   uint32   len;
    uint8    reserved;
-   uint8    control;
+   uint8    ctrl;
 }
 #include "vmware_pack_end.h"
 SCSICDB12;
@@ -331,8 +325,8 @@ typedef struct {
          lun   :3;
    uint8 pagecode;         // only valid when cmddt or evdp is set
    uint8 reserved;        
-   uint8 length;
-   uint8 control;
+   uint8 len;
+   uint8 ctrl;
 } SCSIInquiryCmd;
 
 /* 
@@ -344,9 +338,9 @@ typedef struct {
          obslt :1,         // Obsolete as per SPC-3
          resv  :6;         // The remaining bits are all RESERVED
    uint8 pagecode;         // Only valid when evpd is set
-   uint8 lengthMSB;        // The SPC-3 spec has a 2 byte len field
-   uint8 length;
-   uint8 control;
+   uint8 lenMSB;           // The SPC-3 spec has a 2 byte len field
+   uint8 len;
+   uint8 ctrl;
 } SCSI3InquiryCmd;
 
 typedef struct {
@@ -388,9 +382,7 @@ typedef struct {
 	 tio	     :1,   // device supports TERMINATE I/O PROCESS message
 	 aen	     :1;   // asynchronous event notification capability
    uint8 optlen;	   // length of additional data that follows
-   uint8       :4,
-         tpgs  :2,         // Target Portal Group Support
-               :2;
+   uint8	     :8;
 #define SCSI_TPGS_NONE                       0x0
 #define SCSI_TPGS_IMPLICIT_ONLY              0x1
 #define SCSI_TPGS_IMPLICIT		     SCSI_TPGS_IMPLICIT_ONLY 
@@ -439,9 +431,7 @@ typedef struct {
 	 tio	     :1,   // device supports TERMINATE I/O PROCESS message
 	 aen	     :1;   // asynchronous event notification capability
    uint8 optlen;	   // length of additional data that follows
-   uint8       :4,
-         tpgs  :2,         // Target Portal Group Support
-               :2;
+   uint8	     :8;
    uint8 adr16	     :1,   // device supports 16-bit wide SCSI addresses
 	 adr32	     :1,   // device supports 32-bit wide SCSI addresses
 	 arq	     :1,
@@ -563,34 +553,6 @@ struct SCSIInqPage83ResponseDescriptor {
 #include "vmware_pack_end.h"
 SCSIInqPage83ResponseDescriptor;
 
-/* Page83 structs differ for SCSI2. */
-typedef
-#include "vmware_pack_begin.h"
-struct SCSI2InqPage83ResponseHeader {
-   uint8  devClass      :5,
-          pQual         :3;
-   uint8  pageCode;
-   uint8  reserved;
-   uint8  pageLength;
-}
-#include "vmware_pack_end.h"
-SCSI2InqPage83ResponseHeader;
-
-typedef
-#include "vmware_pack_begin.h"
-struct SCSI2InqPage83ResponseDescriptor {
-   /* Identification Descriptor follows */
-   uint8  codeSet     :4, 
-          reserved    :4; 
-   uint8  idType      :4, 
-          association :2,
-          reserved1   :2; 
-   uint8  reserved2;
-   uint8  idLength;
-}
-#include "vmware_pack_end.h"
-SCSI2InqPage83ResponseDescriptor;
-
 typedef
 #include "vmware_pack_begin.h"
 struct SCSIInquiryVPDResponseHeader {
@@ -679,8 +641,8 @@ typedef struct {
 #define SCSI_MS_PCF_DEFAULT   0x02     // default values
 #define SCSI_MS_PCF_SAVED     0x03     // saved values
    uint8    subpage;
-   uint8    length;        // data length
-   uint8    control;       // control byte
+   uint8    length;  // data length
+   uint8    ctrl;	   // control byte
 } SCSIModeSenseCmd;
 
 
@@ -730,7 +692,7 @@ struct {
 	    pcf	  :2;	   // page control field
    uint8    reserved[4];
    uint16   length;	   // data length
-   uint8    control;       // control byte
+   uint8    ctrl;	   // control byte
 }
 #include "vmware_pack_end.h"
 SCSIModeSense10Cmd;
@@ -742,8 +704,8 @@ typedef struct {
 	    pf	  :1,	   // page format
 	    lun	  :3;	   // logical unit number
    uint8    reserved[2];
-   uint8    length;        // data length
-   uint8    control;       // control byte
+   uint8    len;	   // data length
+   uint8    ctrl;	   // control byte
 } SCSIModeSelectCmd;
 
 typedef 
@@ -755,8 +717,8 @@ struct {
 	    pf	  :1,	   // page format
 	    lun	  :3;	   // logical unit number
    uint8    reserved[5];
-   uint16   length;        // data length
-   uint8    control;       // control byte
+   uint16   len;	   // data length
+   uint8    ctrl;	   // control byte
 }
 #include "vmware_pack_end.h"
 SCSIModeSelect10Cmd;
@@ -1202,7 +1164,17 @@ SCSIReadCapacity16Response;
  * request. These are defined here because multiple SCSI
  * devices need them.
  */
-typedef SCSICDB6 SCSIReadWrite6Cmd;
+typedef 
+#include "vmware_pack_begin.h"
+struct {
+   uint32 opcode:8,
+	  lun:3,
+	  lbn:21;
+   uint8  length;
+   uint8  control;
+}
+#include "vmware_pack_end.h"
+SCSIReadWrite6Cmd;
 
 typedef 
 #include "vmware_pack_begin.h"
@@ -1265,7 +1237,7 @@ struct {
             lun          :3;    // logical unit number
    uint8    resvID;             // SCSI-3: reservation ID
    uint16   resvListLen;        // SCSI-3: reservation list length
-   uint8    control;            // control byte
+   uint8    ctrl;               // control byte
 }
 #include "vmware_pack_end.h"
 SCSIReserveUnitCmd;
@@ -1280,7 +1252,7 @@ struct {
             lun   :3;           // logical unit number
    uint8    resvID;             // SCSI-3: reservation ID
    uint8    reserved[2];
-   uint8    control;            // control byte
+   uint8    ctrl;               // control byte
 } 
 #include "vmware_pack_end.h"
 SCSIReleaseUnitCmd;
@@ -1296,8 +1268,8 @@ struct {
             pf    :1,           // page format
             lun   :3;           // logical unit number
    uint8    reserved;
-   uint16   length;             // data length
-   uint8    control;            // control byte
+   uint16   len;                // data length
+   uint8    ctrl;               // control byte
 }
 #include "vmware_pack_end.h"
 SCSISendDiagnosticCmd;
@@ -1314,8 +1286,8 @@ struct {
             lun     :3;         // logical unit number
    uint32   lbn;                // logical block address
    uint8    reserved;
-   uint16   length;             // verification length
-   uint8    control;            // control byte
+   uint16   len;                // verification length
+   uint8    ctrl;               // control byte
 }
 #include "vmware_pack_end.h"
 SCSIVerify10Cmd;
@@ -1324,25 +1296,7 @@ typedef
 #include "vmware_pack_begin.h"
 struct {
    uint8    opcode;
-   uint8    relAdr  :1,         // relative address
-            bytChk  :1,         // byte
-            blkvfy  :1,         // blank blocks verification, scsi-2 rev 8.
-                    :1,  
-            dpo     :1,         // cache control bit
-            resvd   :3;         // reserved
-   uint64   lbn;                // logical block address
-   uint32   length;             // verification length
-   uint8    reserved;
-   uint8    control;            // control byte
-}
-#include "vmware_pack_end.h"
-SCSIVerify16Cmd;
-
-typedef
-#include "vmware_pack_begin.h"
-struct {
-   uint8    opcode;
-   uint8    polled   :1,         // asynchronous or not
+   uint8    polled   :1,        // asynchronous or not
                      :7;
    uint8    reserved0[2];
 #define SCSI_GESN_CLASS_RSVD0           (1 << 0)
@@ -1656,129 +1610,6 @@ struct {
 SCSIRDSDVDPhysicalInfoLeadin;
 
 
-/*
- * MSF structure for CDs.
- */
-typedef
-#include "vmware_pack_begin.h"
-struct {
-   uint8     minute;
-   uint8     second;
-   uint8     frame;
-}
-#include "vmware_pack_end.h"
-SCSICDMSF;
-
-
-/*
- * ReadCD packet data.
- */
-typedef
-#include "vmware_pack_begin.h"
-struct {
-   uint8     opcode;
-   uint8     obsolete:1,
-             dap:1,
-             expectedSectorType:3,
-             reserved1:3;
-   uint32    lbn;
-   uint8     length[3];
-   uint8     reserved2:1,
-             c2errors:2,
-             mainChannelSelectionBits:5;
-   uint8     subChannelSelectionBits:3,
-             reserved3:5;
-   uint8     control;
-}
-#include "vmware_pack_end.h"
-SCSIReadCDCmd;
-
-
-/*
- * ReadCDMSF packet data.
- */
-typedef
-#include "vmware_pack_begin.h"
-struct {
-   uint8     opcode;
-   uint8     obsolete:1,
-             dap:1,
-             expectedSectorType:3,
-             reserved1:3;
-   uint8     reserved;
-   SCSICDMSF start;
-   SCSICDMSF end;
-   uint8     reserved2:1,
-             c2errors:2,
-             mainChannelSelectionBits:5;
-   uint8     subChannelSelectionBits:3,
-             reserved3:5;
-   uint8     control;
-}
-#include "vmware_pack_end.h"
-SCSIReadCDMSFCmd;
-
-
-/*
- * ReadTOC packet data.
- */
-typedef
-#include "vmware_pack_begin.h"
-struct {
-   uint8     opcode;
-   uint8     reserved1:1,
-             msf:1,
-             reserved2:6;
-   uint8     format:3, /* MMC says 4 bits for eons.  Original ATAPI is only 3 bits. */
-             reserved3:5;
-   uint8     reserved4[3];
-   uint8     trackNumber;
-   uint16    allocationLength;
-   uint8     control;
-}
-#include "vmware_pack_end.h"
-SCSIReadTOCCmd;
-
-
-/*
- * ReadSubChannel packet data.
- */
-typedef
-#include "vmware_pack_begin.h"
-struct {
-   uint8     opcode;
-   uint8     reserved1:1,
-             msf:1,
-             reserved2:6;
-   uint8     reserved3:6,
-             subq:1,
-             reserved4:1;
-   uint8     format;
-   uint8     reserved5[2];
-   uint8     trackNumber;
-   uint16    allocationLength;
-   uint8     control;
-}
-#include "vmware_pack_end.h"
-SCSIReadSubChannelCmd;
-
-
-/*
- * PlayMSF packet data.
- */
-typedef
-#include "vmware_pack_begin.h"
-struct {
-   uint8     opcode;
-   uint8     reserved[2];
-   SCSICDMSF start;
-   SCSICDMSF end;
-   uint8     control;
-}
-#include "vmware_pack_end.h"
-SCSIPlayMSFCmd;
-
-
 /*
  * Host and device status definitions.
  *
@@ -1927,51 +1758,6 @@ SCSICdb_IsRW(uint8 cdb0)        // IN
 }
 
 
-/*
- *---------------------------------------------------------------------------
- *
- * SCSICdb_GetCDBLength --
- *
- *      This function returns length of specified command.  Multibyte
- *      CDB (0x7F) is reported as reserved command.
- *
- * Results:
- *      6 for commands 00-1F
- *      10 for commands 20-5F
- *      16 for commands 80-9F
- *      12 for commands A0-BF
- *      SCSI_GRP_RESERVED for commands 60-7F
- *      SCSI_GRP_VENDOR for commands C0-FF
- *         Both SCSI_GRP_RESERVED & SCSI_GRP_VENDOR are guarateed to have
- *         bigger value than 16.
- *
- * Side effects:
- *      None.
- *
- *---------------------------------------------------------------------------
- */
-
-#define SCSI_GRP_RESERVED  64
-#define SCSI_GRP_VENDOR    65
-
-static INLINE size_t
-SCSICdb_GetCDBLength(uint8 cdb0)    // IN
-{
-   static const unsigned char lengths[] = {
-      6,                 /* 00 - 1F */
-      10,                /* 20 - 3F */
-      10,                /* 40 - 5F */
-      SCSI_GRP_RESERVED, /* 60 - 7F */
-      16,                /* 80 - 9F */
-      12,                /* A0 - BF */
-      SCSI_GRP_VENDOR,   /* C0 - DF */
-      SCSI_GRP_VENDOR,   /* E0 - FF */
-   };
-
-   return lengths[cdb0 >> 5];
-}
-
-
 /*
  *---------------------------------------------------------------------------
  * 
@@ -2027,9 +1813,9 @@ SCSICdb_GetLengthFieldOffset(uint8 cmd)
  */
 
 static INLINE uint16
-SCSI3InquiryLen(const SCSI3InquiryCmd *inqCmd)     // IN
+SCSI3InquiryLen(SCSI3InquiryCmd *inqCmd)        // IN
 {
-  return (inqCmd->lengthMSB << 8) + inqCmd->length;
+  return (inqCmd->lenMSB << 8) + inqCmd->len;
 }
 
 
@@ -2038,7 +1824,7 @@ typedef
 struct SCSICmdInfo {
    uint8 code;
    uint8 xferType;
-   const char *name;
+   char *name;
    uint8 emulation;
 }
 #include "vmware_pack_end.h"
@@ -2248,7 +2034,7 @@ extern SCSICmdInfo scsiCmdInfo[256];
    {SCSI_CMD_SET_CDROM_SPEED,  SCSI_XFER_AUTO,     NULL, SCSI_DONT_EMULATE},	\
    {SCSI_CMD_PLAY_CD,          SCSI_XFER_AUTO,     NULL, SCSI_DONT_EMULATE},	\
    {SCSI_CMD_MECH_STATUS,      SCSI_XFER_TOHOST,   "MECHANISM STATUS", SCSI_DONT_EMULATE}, \
-   {SCSI_CMD_READ_CD,          SCSI_XFER_TOHOST,   "READ CD", SCSI_DONT_EMULATE},          \
+   {SCSI_CMD_READ_CD,          SCSI_XFER_TOHOST,   "READ CD MSF", SCSI_DONT_EMULATE},      \
    {SCSI_CMD_SEND_DVD_STRUCTURE, SCSI_XFER_AUTO,   NULL, SCSI_DONT_EMULATE},	\
    {0xc0,                      SCSI_XFER_AUTO,     NULL, SCSI_DONT_EMULATE},	\
    {0xc1,                      SCSI_XFER_AUTO,     NULL, SCSI_DONT_EMULATE},	\
