@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 2006-2015 VMware, Inc. All rights reserved.
+ * Copyright (C) 2006 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -27,7 +27,6 @@
 
 #include "compat_fs.h"
 #include "compat_kernel.h"
-#include "compat_namei.h"
 #include "compat_version.h"
 
 #include "inode.h"
@@ -35,13 +34,13 @@
 #include "vm_assert.h"
 
 /* HGFS dentry operations. */
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 75)
 static int HgfsDentryRevalidate(struct dentry *dentry,
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 6, 0)
-                                unsigned int flags
+                                struct nameidata *nd);
 #else
-                                struct nameidata *nd
+static int HgfsDentryRevalidate(struct dentry *dentry,
+                                int flags);
 #endif
-);
 
 /* HGFS dentry operations structure. */
 struct dentry_operations HgfsDentryOperations = {
@@ -74,14 +73,15 @@ struct dentry_operations HgfsDentryOperations = {
  *----------------------------------------------------------------------
  */
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 75)
 static int
 HgfsDentryRevalidate(struct dentry *dentry,  // IN: Dentry to revalidate
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 6, 0)
-                     unsigned int flags      // IN: Lookup flags & intent
+                     struct nameidata *nd)   // IN: Lookup flags & intent
 #else
-                     struct nameidata *nd    // IN: Lookup flags & intent
+static int
+HgfsDentryRevalidate(struct dentry *dentry,  // IN: Dentry to revalidate
+                     int flags)              // IN: Lookup flags (e.g. LOOKUP_CONTINUE)
 #endif
-)
 {
    int error;
    LOG(6, (KERN_DEBUG "VMware hgfs: HgfsDentryRevalidate: calling "
@@ -89,26 +89,10 @@ HgfsDentryRevalidate(struct dentry *dentry,  // IN: Dentry to revalidate
 
    ASSERT(dentry);
 
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 6, 0)
-   if (flags & LOOKUP_RCU) {
-      return -ECHILD;
-   }
-#elif defined(LOOKUP_RCU) /* Introduced in 2.6.38 */
-   if (nd && (nd->flags & LOOKUP_RCU)) {
-      return -ECHILD;
-   }
-#endif
-
    /* Just call HgfsRevaliate, which does the right thing. */
    error = HgfsRevalidate(dentry);
    if (error) {
       LOG(4, (KERN_DEBUG "VMware hgfs: HgfsDentryRevalidate: invalid\n"));
-
-      if (dentry->d_inode && S_ISDIR(dentry->d_inode->i_mode)) {
-         shrink_dcache_parent(dentry);
-      }
-      d_drop(dentry);
-
       return 0;
    }
 
