@@ -29,10 +29,10 @@
 #include "driver-config.h"
 
 #include <asm/atomic.h>
-#include <asm/semaphore.h>
 #include "compat_completion.h"
 #include "compat_fs.h"
 #include "compat_kthread.h"
+#include "compat_semaphore.h"
 #include "compat_slab.h"
 #include "compat_spinlock.h"
 #include "compat_version.h"
