@@ -24,19 +24,26 @@
  */
 
 #include "driver-config.h"
-#include <linux/list.h>
 #include <linux/socket.h>
 #include "compat_sock.h"
+#include "compat_list.h"
 
 #include "af_vsock.h"
 #include "util.h"
 
 struct list_head vsockBindTable[VSOCK_HASH_SIZE + 1];
 struct list_head vsockConnectedTable[VSOCK_HASH_SIZE];
-struct list_head vsockSeqTable[VSOCK_HASH_SIZE];
 
-DEFINE_SPINLOCK(vsockTableLock);
-DEFINE_SPINLOCK(vsockSeqTableLock);
+spinlock_t vsockTableLock = SPIN_LOCK_UNLOCKED;
+
+/*
+ * snprintf() wasn't exported until 2.4.10: fall back on sprintf in those
+ * cases.  It's okay since this is only for the debug function for logging
+ * packets.
+ */
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 4, 10)
+#define snprintf(str, size, fmt, args...) sprintf(str, fmt, ## args)
+#endif
 
 
 /*
@@ -76,8 +83,6 @@ VSockVmciLogPkt(char const *function,   // IN
       [VSOCK_PACKET_TYPE_SHUTDOWN]       = "SHUTDOWN",
       [VSOCK_PACKET_TYPE_WAITING_WRITE]  = "WAITING_WRITE",
       [VSOCK_PACKET_TYPE_WAITING_READ]   = "WAITING_READ",
-      [VSOCK_PACKET_TYPE_REQUEST2]       = "REQUEST2",
-      [VSOCK_PACKET_TYPE_NEGOTIATE2]     = "NEGOTIATE2",
    };
 
    written = snprintf(cur, left, "PKT: %u:%u -> %u:%u",
@@ -133,14 +138,6 @@ VSockVmciLogPkt(char const *function,   // IN
 
       break;
 
-   case VSOCK_PACKET_TYPE_REQUEST2:
-   case VSOCK_PACKET_TYPE_NEGOTIATE2:
-      written = snprintf(cur, left, ", %s, size = %"FMT64"u, "
-                         "proto = %u",
-                         typeStrings[pkt->type], pkt->u.size,
-                         pkt->proto);
-      break;
-
    default:
       written = snprintf(cur, left, ", unrecognized type");
    }
@@ -157,12 +154,12 @@ VSockVmciLogPkt(char const *function,   // IN
       goto error;
    }
 
-   LOG(8, ("%s", buf));
+   Log("%s", buf);
 
    return;
 
 error:
-   LOG(8, ("could not log packet\n"));
+   Log("could not log packet\n");
 }
 
 
@@ -194,10 +191,6 @@ VSockVmciInitTables(void)
    for (i = 0; i < ARRAYSIZE(vsockConnectedTable); i++) {
       INIT_LIST_HEAD(&vsockConnectedTable[i]);
    }
-
-   for (i = 0; i < ARRAYSIZE(vsockSeqTable); i++) {
-      INIT_LIST_HEAD(&vsockSeqTable[i]);
-   }
 }
 
 
@@ -269,40 +262,6 @@ __VSockVmciInsertConnected(struct list_head *list,   // IN
 }
 
 
-/*
- *----------------------------------------------------------------------------
- *
- * __VSockVmciInsertSeq --
- *
- *    Inserts socket into the sequential table.
- *
- *    Note that this assumes any necessary locks are held.
- *
- * Results:
- *    None.
- *
- * Side effects:
- *    The reference count for sk is incremented.
- *
- *----------------------------------------------------------------------------
- */
-
-void
-__VSockVmciInsertSeq(struct list_head *list,   // IN
-                     struct sock *sk)          // IN
-{
-   VSockVmciSock *vsk;
-
-   ASSERT(list);
-   ASSERT(sk);
-
-   vsk = vsock_sk(sk);
-
-   sock_hold(sk);
-   list_add(&vsk->seqTable, list);
-}
-
-
 /*
  *----------------------------------------------------------------------------
  *
@@ -369,39 +328,6 @@ __VSockVmciRemoveConnected(struct sock *sk)  // IN
 }
 
 
-/*
- *----------------------------------------------------------------------------
- *
- * __VSockVmciRemoveSeq --
- *
- *    Removes socket from the sequential table.
- *
- *    Note that this assumes any necessary locks are held.
- *
- * Results:
- *    None.
- *
- * Side effects:
- *    The reference count for sk is decremented.
- *
- *----------------------------------------------------------------------------
- */
-
-void
-__VSockVmciRemoveSeq(struct sock *sk)  // IN
-{
-   VSockVmciSock *vsk;
-
-   ASSERT(sk);
-   ASSERT(__VSockVmciInSeqTable(sk));
-
-   vsk = vsock_sk(sk);
-
-   list_del_init(&vsk->seqTable);
-   sock_put(sk);
-}
-
-
 /*
  *----------------------------------------------------------------------------
  *
@@ -431,12 +357,12 @@ __VSockVmciFindBoundSocket(struct sockaddr_vm *addr)  // IN
 
 
    list_for_each_entry(vsk, vsockBoundSockets(addr), boundTable) {
-      if (VSockAddr_EqualsAddrAny(addr, &vsk->localAddr)) {
+      if (VSockAddr_EqualsAddr(addr, &vsk->localAddr)) {
          sk = sk_vsock(vsk);
 
          /* We only store stream sockets in the bound table. */
-         ASSERT(sk->sk_socket ?
-                   sk->sk_socket->type == SOCK_STREAM :
+         ASSERT(sk->compat_sk_socket ?
+                   sk->compat_sk_socket->type == SOCK_STREAM :
                    1);
          goto found;
       }
@@ -549,35 +475,7 @@ __VSockVmciInConnectedTable(struct sock *sk)     // IN
 }
 
 
-/*
- *----------------------------------------------------------------------------
- *
- * __VSockVmciInSeqTable --
- *
- *    Determines whether the provided socket is in the sequential table.
- *
- * Results:
- *    TRUE is socket is in sequential table, FALSE otherwise.
- *
- * Side effects:
- *    None.
- *
- *----------------------------------------------------------------------------
- */
-
-Bool
-__VSockVmciInSeqTable(struct sock *sk)     // IN
-{
-   VSockVmciSock *vsk;
-
-   ASSERT(sk);
-
-   vsk = vsock_sk(sk);
-
-   return !list_empty(&vsk->seqTable);
-}
-
-
+#ifdef VMX86_TOOLS
 /*
  *----------------------------------------------------------------------------
  *
@@ -719,11 +617,13 @@ void
 VSockVmciRemovePending(struct sock *listener,   // IN: listening socket
                        struct sock *pending)    // IN: pending connection
 {
+   VSockVmciSock *vlistener;
    VSockVmciSock *vpending;
 
    ASSERT(listener);
    ASSERT(pending);
 
+   vlistener = vsock_sk(listener);
    vpending = vsock_sk(pending);
 
    list_del_init(&vpending->pendingLinks);
@@ -954,3 +854,4 @@ VSockVmciIsPending(struct sock *sk)     // IN: socket
    vsk = vsock_sk(sk);
    return !list_empty(&vsk->pendingLinks);
 }
+#endif
